/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02258
 |         DRUG ABUSE TREATMENT OUTCOME STUDY (DATOS), 1991-1994:
 |                            [UNITED STATES]
 |                     (DATASET 0001:  INTAKE 1 DATA)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02258-0001-statasetup.do)
 |
 **************************************************************************/

set mem 40m  /* Allocating 40 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Drug Abuse Treatment Outcome Study (DATOS), 1991-1994: [United States], Dataset 0001"

#delimit ;
label define MODALITY  1 "RESIDENTIAL" 2 "SHORT-TERM INPATIENT"
                       3 "METHADONE MAINTENANCE" 4 "OUTPATIENT DRUG FREE" ;
label define FORM      1 "NOV91" 2 "OCT92" ;
label define ADC1      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define ADC3      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define ATLI      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AA3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AA3A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "STILL IN SERVICE"
                       2 "HONORABLE" 3 "GENERAL" 4 "MEDICAL" 5 "UNDESIRABLE"
                       6 "DISHONORABLE" 7 "OTHER" ;
label define AA4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AA4A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PUERTO RICAN" 2 "MEXICAN"
                       3 "CUBAN" 7 "OTHER" 15 "MIXED" ;
label define AA4B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       4 "BLACK OR AFRICAN AMERICAN" 5 "WHITE OR CAUCASIAN"
                       6 "OTHER" 7 "HISPANIC" ;
label define AA8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ONLY ENGLISH"
                       2 "ENGLISH AND OTHER LANGUAGE(S)"
                       3 "ONLY OTHER LANGUAGE(S)" ;
label define AA9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AA9A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SPANISH" 2 "FRENCH"
                       3 "GERMAN" 4 "OTHER" ;
label define AA9B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "ONLY (OTH. LANG. FROM A9A)"
                       2 "MOSTLY (OTH. LANG. FROM A9A)" 3 "ONLY ENGLISH"
                       4 "MOSTLY ENGLISH" 5 "(OTH. LANG. FROM A9A) & ENGLISH" ;
label define AA10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MARRIED"
                       2 "LEGALLY SEPARATED" 3 "DIVORCED" 4 "WIDOWED"
                       5 "LIVING W/SOMEONE AS MARRIED" 6 "NEVER MARRIED" ;
label define AA10B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AA11_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "0-52 WKS" 2 "53-104 WKS"
                       3 "105-156 WKS" 4 "157-208 WKS" 5 "209-260 WKS"
                       6 "261-312 WKS" 7 "313-364 WKS" 8 "365-416 WKS"
                       9 "417-468 WKS" 10 "469-520 WKS" 11 "521-572 WKS"
                       12 "573-624 WKS" 13 "625-676 WKS" 14 "677-728 WKS"
                       15 "729-780 WKS" 16 "781-832 WKS" 17 "833-884 WKS"
                       18 "885-936 WKS" 19 "937-988 WKS" 20 "989-1040 WKS"
                       21 "1041+ WKS" ;
label define AA12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "ONE-FAMILY HOUSE/DUPLEX/CONDO"
                       2 "MOBILE HOME/TRAILER"
                       3 "APARTMENT BLDG/MULTIPLE DWELLING"
                       4 "HOTEL/ROOMING HOUSE/BOARDING HOUSE"
                       5 "HOSPITAL OR MED INSTITUTION"
                       6 "IN JAIL/PRISON/JUVENILE DETENTION"
                       7 "RES DRUG TX CENTER"
                       8 "OTHER GROUP RESIDENCE/HALFWAY HOUSE"
                       9 "IN HOMELESS SHELTER"
                       10 "ON STREET (NO REGULAR PLACE)"
                       11 "(IF VOL.:) OTHER" ;
label define AA13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "W/SPOUSE OR SEXUAL PARTNER/CHILDREN"
                       2 "W/SPOUSE OR SEXUAL PARTNER ONLY"
                       3 "W/CHILDREN ONLY" 4 "W/BOTH PARENTS"
                       5 "W/MOTHER ONLY" 6 "W/FATHER ONLY"
                       7 "W/PARENT(S) AND OWN CHILDREN"
                       8 "W/OTHER FAMILY ONLY/COMBINATION 1-7"
                       9 "W/FOSTER PARENTS"
                       10 "W/FAMILY/FRIENDS/BOARDERS/ROOMMATE"
                       11 "W/FRIENDS OR ROOMMATE ONLY" 12 "ALONE"
                       13 "INSTITUTION OR CLOSED FACILITY"
                       14 "NO STABLE ARRANGEMENT" 15 "OTHER" ;
label define AA14_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define AA14_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define AA14_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define AA14_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define AA14_5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define AA14_6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define AA15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AA15B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "ONLY (OTHER LANGAUGE FROM A9A)"
                       2 "MOSTLY (OTHER LANGAUGE FROM A9A)" 3 "ONLY ENGLISH"
                       4 "MOSTLY ENGLISH"
                       5 "(OTHER LANGUAGE FROM A9A) & ENGLISH" ;
label define AA16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define AA17_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AB1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 21 "21+" ;
label define AB1A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AB1B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AB1C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "MIDDLE SCHOOL (JUNIOR HIGH)" 2 "HIGH SCHOOL"
                       3 "JUNIOR (2-YR) COLLEGE"
                       4 "4-YR COLLEGE OR UNIVERSITY"
                       5 "TECHNICAL/TRADE/VOCATIONAL" 6 "JOB CORPS PROG"
                       7 "SPECIAL EDUCATION PROG" 8 "OTHER" ;
label define AB2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AB2A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "DIPLOMA" 2 "GED" ;
label define AB3_1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define AB3_2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define AB3_3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define AB3_4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define AB3_5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define AB3_6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define AB3_7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define AB4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BETTER THAN AVERAGE"
                       2 "AVERAGE" 3 "NOT SO GOOD" ;
label define AB4A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "DID AS WELL AS COULD"
                       2 "COULD HAVE DONE BETTER" ;
label define AB4B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AB5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AB5A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "4+" ;
label define AB6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AB6A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AB7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AB7A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AB7B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AB7C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AB7C_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AB7D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AB7E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AB7E_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AB8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AB8A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LAST YR ONLY"
                       2 "BEFORE LAST YR" ;
label define AB8B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AB8C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AB9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AB10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AB10A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AB10B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "EXPIRED" 2 "SUSPENDED"
                       3 "REVOKED" ;
label define AB11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "SOME"
                       2 "ALL OF THE TIME" ;
label define AC1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AC1A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define AC1A3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 89 "1980-1989" ;
label define AC1B1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define AC1B3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AC2_1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "SHORTAGE OF DRUGS AVAILABLE"
                       2 "DRUGS OF POOR QUALITY" 3 "LOST DRUG CONNECTION"
                       9 "OTHER PROBS WITH AVAILABILITY"
                       11 "DRUGS COST TOO MUCH/NOT SUPPORT HABIT"
                       12 "NOT ENOUGH MONEY TO BUY DRUGS"
                       13 "NOT ENOUGH MONEY TO BUY OTHER THINGS"
                       14 "WANTED TO BE SELF-SUPPORTING"
                       19 "OTHER FINANCIAL PROBS" 21 "WANT TO GET OFF DRUGS"
                       22 "TO CUT DOWN ON THE SIZE OF HABIT"
                       23 "GETTING DISGUSTED WITH LIFESTYLE"
                       24 "WANT TO ENTER OR STAY IN SCHOOL"
                       25 "WANT TO FIND NEW FRIENDS" 26 "BECAME RELIGIOUS"
                       29 "OTHER DESIRE TO CHANGE LIFESTYLE"
                       31 "HAVE DRUG RELATED CONTAGIOUS DISEASE"
                       32 "DRUGS (MAKE/MADE) ME SICK"
                       33 "AFRAID OF GETTING AIDS, OTHR DISEASE"
                       34 "HAD HLTH PROBS UNRELATED TO DRUGS"
                       35 "PREGNANT OR WANT TO GET PREGNANT"
                       36 "WANT TO IMPROVE MY GENERAL HEALTH"
                       37 "WANT TO IMPROVE MY MENTAL HEALTH"
                       39 "OTHER HEALTH REASON"
                       41 "WANT TO SAVE MY MARRIAGE/RELATINSHP"
                       42 "TO IMPROVE MY RELATIONS W/FAMILY"
                       43 "TO AVOID LOSING CUSTODY OF CHILDRN"
                       44 "WANT TO GET MY CHILDREN BACK"
                       49 "OTHER INTERPERSONAL REASONS"
                       51 "TO AVOID BEING INVLVD CRIMINL ACTS"
                       52 "WANT TO AVOID ARREST" 53 "COURT MANDATE"
                       54 "HAVE UPCOMING COURT HEARING"
                       59 "OTHER LEGAL REASON"
                       61 "TO BECOME ELIGIBLE FOR PUB ASSIST"
                       62 "TO BECOME ELIGIBLE FOR MEDICAL SERVS"
                       63 "TO BECOME ELIGIBLE FOR JOB SERVICES"
                       69 "OTHER ACCESS TO SERVICES"
                       71 "WANT TO KEEP JOB OR FIND BETTER JOB"
                       72 "TO PREVENT PROBS WITH MY SUPERVISOR"
                       73 "TO PREVENT PROBS WITH MY CO-WORKERS"
                       74 "OTHER JOB-RELATED PROBS" 75 "DO BETTER IN SCHOOL"
                       76 "PREVENT PROBS W/PRINCIPAL/TEACHERS"
                       77 "PREVENT PROBS WITH OTHER STUDENTS"
                       78 "CONDITION OF SUSPENSION"
                       79 "OTHER SCHOOL-RELATED PROBS" 81 "SPOUSE/PARTNER"
                       82 "FAMILY" 83 "FRIENDS" 84 "SCHOOL"
                       85 "JOB OR EMPLOYER"
                       86 "LEGAL (BESIDES COURT MANDATE)" 87 "TX STAFF"
                       88 "TX CLIENTS" 89 "OTHER PRESSURE" 91 "OTHER" ;
label define AC2A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "SHORTAGE OF DRUGS AVAILABLE"
                       2 "DRUGS OF POOR QUALITY" 3 "LOST DRUG CONNECTION"
                       9 "OTHER PROBS WITH AVAILABILITY"
                       11 "DRUGS COST TOO MUCH/NOT SUPPORT HABIT"
                       12 "NOT ENOUGH MONEY TO BUY DRUGS"
                       13 "NOT ENOUGH MONEY TO BUY OTHER THINGS"
                       14 "WANTED TO BE SELF-SUPPORTING"
                       19 "OTHER FINANCIAL PROBS" 21 "WANT TO GET OFF DRUGS"
                       22 "WANT TO CUT DOWN ON SIZE OF HABIT"
                       23 "GETTING DISGUSTED WITH LIFESTYLE"
                       24 "WANT TO ENTER OR STAY IN SCHOOL"
                       25 "WANT TO FIND NEW FRIENDS" 26 "BECAME RELIGIOUS"
                       29 "OTHER DESIRE TO CHANGE LIFESTYLE"
                       31 "HAVE DRUG RELATED CONTAGIOUS DISEASE"
                       32 "DRUGS (MAKE/MADE) ME SICK"
                       33 "AFRAID OF GETTING AIDS, OTHR DISEASE"
                       34 "HAD HLTH PROBS UNRELATED TO DRUGS"
                       35 "PREGNANT OR WANT TO GET PREGNANT"
                       36 "WANT TO IMPROVE MY GENERAL HEALTH"
                       37 "WANT TO IMPROVE MY MENTAL HEALTH"
                       39 "OTHER HEALTH REASON"
                       41 "WANT TO SAVE MY MARRIAGE/ RELATIONSHIP"
                       42 "WANT TO IMPROVE MY RELATIONS W/FAMILY"
                       43 "TO AVOID LOSING CUSTODY OF CHILDRN"
                       44 "WANT TO GET MY CHILDREN BACK"
                       49 "OTHER INTERPERSONAL REASONS"
                       51 "TO AVOID BEING INVLVD CRIMINL ACTS"
                       52 "WANT TO AVOID ARREST" 53 "COURT MANDATE"
                       54 "HAVE UPCOMING COURT HEARING"
                       59 "OTHER LEGAL REASON"
                       61 "TO BECOME ELIGIBLE FOR PUB ASST"
                       62 "TO BECOME ELIGIBLE FOR MEDICAL SERVS"
                       63 "TO BECOME ELIGIBLE FOR JOB SERVICES"
                       69 "OTHER ACESS TO SERVICES"
                       71 "WANT TO KEEP A JOB OR FIND BETTER JOB"
                       72 "TO PREVENT PROBS WITH MY SUPERVISOR"
                       73 "TO PREVENT PROBS WITH MY CO-WORKERS"
                       74 "OTHER JOB-RELATED PROBS" 75 "DO BETTER IN SCHOOL"
                       76 "PREVENT PROBS W/PRINCIPAL/TEACHERS"
                       77 "PREVENT PROBS WITH OTHER STUDENTS"
                       78 "CONDITION OF SUSPENSION"
                       79 "OTHER SCHOOL-RELATED PROBS" 81 "SPOUSE/PARTNER"
                       82 "FAMILY" 83 "FRIENDS" 84 "SCHOOL"
                       85 "JOB OR EMPLOYER"
                       86 "LEGAL (BESIDES COURT MANDATE)" 87 "TX STAFF"
                       88 "TX CLIENTS" 89 "OTHER PRESSURE" 91 "OTHER" ;
label define AC2A2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "SHORTAGE OF DRUGS AVAILABLE"
                       2 "DRUGS OF POOR QUALITY" 3 "LOST DRUG CONNECTION"
                       9 "OTHER PROBS WITH AVAILABILITY"
                       11 "DRUGS COST TOO MUCH/NOT SUPPORT HABIT"
                       12 "NOT ENOUGH MONEY TO BUY DRUGS"
                       13 "NOT ENOUGH MONEY TO BUY OTHER THINGS"
                       14 "WANTED TO BE SELF-SUPPORTING"
                       19 "OTHER FINANCIAL PROBS" 21 "WANT TO GET OFF DRUGS"
                       22 "WANT TO CUT DOWN ON THE SIZE OF HABIT"
                       23 "GETTING DISGUSTED WITH LIFESTYLE"
                       24 "WANT TO ENTER OR STAY IN SCHOOL"
                       25 "WANT TO FIND NEW FRIENDS" 26 "BECAME RELIGIOUS"
                       29 "OTHER DESIRE TO CHANGE LIFESTYLE"
                       31 "HAVE DRUG RELATED CONTAGIOUS DISEASE"
                       32 "DRUGS (MAKE/MADE) ME SICK"
                       33 "AFRAID OF GETTING AIDS, OTHER DISEASE"
                       34 "HAD HEALTH PROBS UNRELATED TO DRUGS"
                       35 "PREGNANT OR WANT TO GET PREGNANT"
                       36 "WANT TO IMPROVE MY GENERAL HEALTH"
                       37 "WANT TO IMPROVE MY MENTAL HEALTH"
                       39 "OTHER HEALTH REASON"
                       41 "WANT TO SAVE MY MARRIAGE/ RELATIONSHIP"
                       42 "WANT TO IMPROVE MY RELATIONS W/FAMILY"
                       43 "TO AVOID LOSING CUSTODY OF CHILDRN"
                       44 "WANT TO GET MY CHILDREN BACK"
                       49 "OTHER INTERPERSONAL REASONS"
                       51 "TO AVOID BEING INVLVD CRIMINL ACTS"
                       52 "WANT TO AVOID ARREST" 53 "COURT MANDATE"
                       54 "HAVE UPCOMING COURT HEARING"
                       59 "OTHER LEGAL REASON"
                       61 "TO BECOME ELIGIBLE FOR PUB ASSIST"
                       62 "TO BECOME ELIGIBLE FOR MEDICAL SERVS"
                       63 "TO BECOME ELIGIBLE FOR JOB SERVICES"
                       69 "OTHER ACESS TO SERVICES"
                       71 "WANT TO KEEP JOB OR FIND BETTER JOB"
                       72 "TO PREVENT PROBS WITH MY SUPERVISOR"
                       73 "TO PREVENT PROBS WITH MY CO-WORKERS"
                       74 "OTHER JOB-RELATED PROBS" 75 "DO BETTER IN SCHOOL"
                       76 "PREVENT PROBS W/PRINCIPAL/TEACHERS"
                       77 "PREVENT PROBS WITH OTHER STUDENTS"
                       78 "CONDITION OF SUSPENSION"
                       79 "OTHER SCHOOL-RELATED PROBS" 81 "SPOUSE/PARTNER"
                       82 "FAMILY" 83 "FRIENDS" 84 "SCHOOL"
                       85 "JOB OR EMPLOYER"
                       86 "LEGAL (BESIDES COURT MANDATE)" 87 "TX STAFF"
                       88 "TX CLIENTS" 89 "OTHER PRESSURE" 91 "OTHER" ;
label define AC2A3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "SHORTAGE OF DRUGS AVAILABLE"
                       2 "DRUGS OF POOR QUALITY" 3 "LOST DRUG CONNECTION"
                       9 "OTHER PROBS WITH AVAILABILITY"
                       11 "DRUGS COST TOO MUCH/NOT SUPPORT HABIT"
                       12 "NOT ENOUGH MONEY TO BUY DRUGS"
                       13 "NOT ENOUGH MONEY TO BUY OTHER THINGS"
                       14 "WANTED TO BE SELF-SUPPORTING"
                       19 "OTHER FINANCIAL PROBS" 21 "WANT TO GET OFF DRUGS"
                       22 "WANT TO CUT DOWN ON THE SIZE OF HABIT"
                       23 "GETTING DISGUSTED WITH LIFESTYLE"
                       24 "WANT TO ENTER OR STAY IN SCHOOL"
                       25 "WANT TO FIND NEW FRIENDS" 26 "BECAME RELIGIOUS"
                       29 "OTHER DESIRE TO CHANGE LIFESTYLE"
                       31 "HAVE DRUG RELATED CONTAGIOUS DISEASE"
                       32 "DRUGS (MAKE/MADE) ME SICK"
                       33 "AFRAID OF GETTING AIDS, OTHER DISEASE"
                       34 "HAD HEALTH PROBS UNRELATED TO DRUGS"
                       35 "PREGNANT OR WANT TO GET PREGNANT"
                       36 "WANT TO IMPROVE MY GENERAL HEALTH"
                       37 "WANT TO IMPROVE MY MENTAL HEALTH"
                       39 "OTHER HEALTH REASON"
                       41 "WANT TO SAVE MY MARRIAGE/ RELATIONSHIP"
                       42 "WANT TO IMPROVE MY RELATIONS W/FAMILY"
                       43 "TO AVOID LOSING CUSTODY OF CHILDRN"
                       44 "WANT TO GET MY CHILDREN BACK"
                       49 "OTHER INTERPERSONAL REASONS"
                       51 "TO AVOID BEING INVLVD CRIMINL ACTS"
                       52 "WANT TO AVOID ARREST" 53 "COURT MANDATE"
                       54 "HAVE UPCOMING COURT HEARING"
                       59 "OTHER LEGAL REASON"
                       61 "TO BECOME ELIGIBLE FOR PUB ASSIST"
                       62 "TO BECOME ELIGIBLE FOR MEDICAL SERVS"
                       63 "TO BECOME ELIGIBLE FOR JOB SERVICES"
                       69 "OTHER ACESS TO SERVICES"
                       71 "WANT TO KEEP JOB OR FIND BETTER JOB"
                       72 "TO PREVENT PROBS WITH MY SUPERVISOR"
                       73 "TO PREVENT PROBS WITH MY CO-WORKERS"
                       74 "OTHER JOB-RELATED PROBS" 75 "DO BETTER IN SCHOOL"
                       76 "PREVENT PROBS W/PRINCIPAL/TEACHERS"
                       77 "PREVENT PROBS WITH OTHER STUDENTS"
                       78 "CONDITION OF SUSPENSION"
                       79 "OTHER SCHOOL-RELATED PROBS" 81 "SPOUSE/PARTNER"
                       82 "FAMILY" 83 "FRIENDS" 84 "SCHOOL"
                       85 "JOB OR EMPLOYER"
                       86 "LEGAL (BESIDES COURT MANDATE)" 87 "TX STAFF"
                       88 "TX CLIENTS" 89 "OTHER PRESSURE" 91 "OTHER" ;
label define AC3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YOUR OWN IDEA"
                       2 "SOMEONE ELSES IDEA" ;
label define AC3A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "SELF-REFERRAL"
                       1 "MEDICAL SERVICE" 10 "COMMUNITY AGENCY"
                       20 "LEGAL SYSTEM (NOT PROBATION OR PAROLE)"
                       30 "PROBATION AND PAROLE" 40 "PRISON SYSTEM"
                       50 "FAMILY OR FRIENDS" 60 "SCHOOL" 70 "EMPLOYER"
                       80 "VETERAN" 90 "OTHER" ;
label define AC4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AC4A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "SELF-REFERRAL"
                       1 "MEDICAL SERVICE" 10 "COMMUNITY AGENCY"
                       20 "LEGAL SYSTEM (NOT PROBATION OR PAROLE)"
                       30 "PROBATION AND PAROLE" 40 "PRISON SYSTEM"
                       50 "FAMILY OR FRIENDS" 60 "SCHOOL" 70 "EMPLOYER"
                       80 "VETERAN" 90 "OTHER" ;
label define AC4A2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "SELF-REFERRAL"
                       1 "MEDICAL SERVICE" 10 "COMMUNITY AGENCY"
                       20 "LEGAL SYSTEM (NOT PROBATION OR PAROLE)"
                       30 "PROBATION AND PAROLE" 40 "PRISON SYSTEM"
                       50 "FAMILY OR FRIENDS" 60 "SCHOOL" 70 "EMPLOYER"
                       80 "VETERAN" 90 "OTHER" ;
label define AC5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SELF" 2 "SOMEONE ELSE" ;
label define AC6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WANTED THIS TYPE"
                       2 "DID NOT CARE WHICH TYPE" 3 "WANTED ANOTHER TYPE" ;
label define AC6A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "METHADONE MAINTENANCE"
                       2 "THERAPEUTIC COMMUNITY OR RESIDENTIAL"
                       3 "SHORT-TERM INPATIENT" 4 "NON-METHADONE OUTPATIENT"
                       5 "OTHER" ;
label define AC7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AC7A_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define AC7A_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define AC7A_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define AC7A_4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define AC7A_5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define AC7A_6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define AC7A_7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "STATE" 9 "UCARE"
                       10 "WORKERS COMPENSATION" 11 "MAXICARE" 12 "KAISER"
                       13 "OTHER" ;
label define AC7B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "OWN NAME"
                       2 "OTHER FAMILY MEMBER" ;
label define AC7C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "PROG CHARGES NO FEE" ;
label define AC7D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "LESS THAN HALF"
                       2 "HALF OR MORE" 3 "ALL"
                       4 "(IF VOL:) PROG CHARGES NO FEES" ;
label define AC7E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SELF PAY (YOUR MONEY)"
                       2 "FAMILY, RELATIVES" 3 "WORKERS COMPENSATION"
                       4 "OTHER (SPECIFY)" ;
label define AC8_0     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define AC8_1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define AC8_2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define AC8_3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define AC8_4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define AC8_5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define AC8_6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define AC8_7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define AC8_8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define AC8_9     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define AC9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" 3 "UNCERTAIN" ;
label define AC9A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AC9B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "REQUIRED, STIPULATED"
                       2 "SUGGESTED, ENCOURAGED" ;
label define AC9C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AC9D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AC9E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "NOTHING/ILL BE GIVEN ANOTHER CHANCE"
                       2 "GIVEN A TECHNICAL VIOLATION"
                       3 "INCREASED SUPERVISION OR MONITORING"
                       4 "RETURNED TO (JAIL/PRISON)" 5 "OTHER (SPECIFY)" ;
label define AC10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "LIVING AT THE TX FACILITY" 1 "WALK" 2 "DRIVE"
                       3 "PUB TRANSPORTATION" 4 "RIDE FROM FAMILY/FRIEND"
                       5 "TAXI CAB" 6 "PROG WILL PROVIDE TRANSPORTATION"
                       7 "OTHER (SPECIFY)" ;
label define AC11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "POOR" 2 "FAIR" 3 "GOOD"
                       4 "VERY GOOD" ;
label define AD1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AD1A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AD2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD2A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AD2B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AD2B_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AD3A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AD3B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITH THE PAST YR" 3 "MORE THAN 1 YR AGO" ;
label define AD3B_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AD4A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AD4B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AD4B_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AD5A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AD6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AD7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "DID NOT DRINK BEER/WINE OR LIQUOR"
                       1 "LESS THAN 1 DAY A MONTH" 2 "1-3 DAYS/MONTH"
                       3 "1-2 DAYS/WEEK" 4 "3-4 DAYS/WEEK" 5 "5-6 DAYS/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AD8A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AD9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AD9_M     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD9A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER"
                       1 "LESS THAN 1 DAY A MONTH" 2 "1-3 DAYS/MONTH"
                       3 "1-2 DAYS/WEEK" 4 "3-4 DAYS/WEEK" 5 "5-6 DAYS/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AD9B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD9C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER"
                       1 "LESS THAN 1 DAY A MONTH" 2 "1-3 DAYS/MONTH"
                       3 "1-2 DAYS/WEEK" 4 "3-4 DAYS/WEEK" 5 "5-6 DAYS/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AD9D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD9E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER"
                       1 "LESS THAN 1 DAY A MONTH" 2 "1-3 DAYS/MONTH"
                       3 "1-2 DAYS/WEEK" 4 "3-4 DAYS/WEEK" 5 "5-6 DAYS/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AD9F      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AD10A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN 1 DAY A MONTH"
                       2 "1-3 DAYS/MONTH" 3 "1-2 DAYS/WEEK" 4 "3-4 DAYS/WEEK"
                       5 "5-6 DAYS/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AD10B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD10C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AD10D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AD10D_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define AD12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define AD13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AD13A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AD14A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD14B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD14C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD14D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AD14E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AD15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD15A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AD16_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD16A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SHORT-TERM INPATIENT"
                       2 "LONG-TERM RESIDENTIAL" 3 "HALFWAY HOUSE"
                       4 "OUTPATIENT" 5 "OTHER" ;
label define AD17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AD17A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AD17A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD17B3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AD18A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AD18A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AD19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AD19A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "1-5 CIGARETTES"
                       2 "6-15 CIGARETTES" 3 "16-25 CIGARETTES"
                       4 "26-35 CIGARETTES" 5 "OVER 35 CIGARETTES" ;
label define AD20_0    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define AD20_1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define AD20_2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define AD20_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define AE1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "1 OR 2 TIMES"
                       2 "3-5 TIMES" 3 "6-10 TIMES" 4 "11-49 TIMES"
                       5 "50-99 TIMES" 6 "100-199 TIMES" 7 "200+ TIMES" ;
label define AE1A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE1B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT USED AT ALL OVER THE PERIOD"
                       1 "LESS THAN ONCE/MONTH" 2 "1-3 TIMES/MONTH"
                       3 "1-2 TIMES/WEEK" 4 "3-4 TIMES/WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AE1C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE1D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE1E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEFORE ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE1E_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE1F      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEFORE ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE1F_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE1G      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER USED"
                       1 "1 OR 2 TIMES" 2 "3-5 TIMES" 3 "6-10 TIMES"
                       4 "11-49 TIMES" 5 "50-99 TIMES" 6 "100-199 TIMES"
                       7 "200+ TIMES" ;
label define AE2A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE2B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT USED AT ALL OVER THE PERIOD"
                       1 "LESS THAN ONCE/MONHT" 2 "1-3 TIMES/MONTH"
                       3 "1-2 TIMES/WEEK" 4 "3-4 TIMES/WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AE2C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE2D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE2E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE2F3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE2G      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH"
                       2 "SMOKING (CRACK)" 3 "INHALING, SNORTING, SNIFFING"
                       4 "INJECTING INTO A VEIN" 5 "INJECTING SOMEWHERE"
                       6 "FREEBASE" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE2H      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE2I      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AE2J3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE2K      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "IN A TX PROG"
                       2 "IN JAIL/PRISON/JUVENILE DETENTION"
                       3 "STOPPED ON OWN" 4 "OTHER" ;
label define AE2L      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE2M      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE2M_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE2N      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE2N_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE2O      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE2P      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "BY SMOKING IT (CRACK)"
                       3 "BY INHALING, SNORTING OR SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "FREEBASING"
                       7 "SOME OTHER WAY (SPECIFY)" 8 "USED ONCE"
                       9 "LACED WITH MARIJUANA" 10 "PUSHES" 11 "OTHER" ;
label define AE2Q      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE2R      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE2R_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE2S      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER USED"
                       1 "1 OR 2 TIMES" 2 "3-5 TIMES" 3 "6-10 TIMES"
                       4 "11-49 TIMES" 5 "50-99 TIMES" 6 "100-199 TIMES"
                       7 "200+ TIMES" ;
label define AE3A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE3B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT USED AT ALL OVER THE PERIOD"
                       1 "LESS THAN ONCE/MONTH" 2 "1-3 TIMES/MONTH"
                       3 "1-2 TIMES/WEEK" 4 "3-4 TIMES/WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AE3C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE3D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE3E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE3F3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE3G      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH"
                       2 "BY SMOKING IT (CRACK)"
                       3 "BY INHALING, SNORTING OR SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "FREEBASING"
                       7 "SOME OTHER WAY (SPECIFY)" ;
label define AE3H      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE3I      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AE3J3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE3K      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "IN A TX PROG" 2 "IN JAIL"
                       3 "STOPPED ON YOUR OWN" 4 "OTHER" ;
label define AE3L      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE3M      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE3M_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE3N      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE3N_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE3O      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE3P      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "BY SMOKING IT (CRACK)"
                       3 "BY INHALING, SNORTING OR SNIFFING IT"
                       4 "BY INJECTING IT INTO A VEIN"
                       5 "BY INJECTING IT SOMEWHERE ELSE" 6 "FREEBASING"
                       7 "SOME OTHER WAY (SPECIFY)" ;
label define AE3Q      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE3R      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE3R_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE3S      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE3T      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING, SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE4A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "DARVON"
                       2 "DOLENE" 3 "SK-65" 4 "WYGESIC" 5 "LEVO-DROMORAN"
                       6 "PERCODAN" 7 "DEMEROL" 8 "DILAUDID"
                       9 "TYLENOL with CODEINE" 10 "PHENAPHEN with CODEINE"
                       11 "TALWIN" 12 "TALWIN NX" 13 "TALACEN"
                       14 "PROPOXYPHENE" 15 "CODEINE" 16 "ANILERIDINE"
                       17 "MORPHINE" 18 "METHADONE" 19 "STADOL" 20 "DARVOCET"
                       21 "LOMOTIL" 22 "PAREGORIC" 92 "OTHER" ;
label define AE4A2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "DARVON"
                       2 "DOLENE" 3 "SK-65" 4 "WYGESIC" 5 "LEVO-DROMORAN"
                       6 "PERCODAN" 7 "DEMEROL" 8 "DILAUDID"
                       9 "TYLENOL with CODEINE" 10 "PHENAPHEN with CODEINE"
                       11 "TALWIN" 12 "TALWIN NX" 13 "TALACEN"
                       14 "PROPOXYPHENE" 15 "CODEINE" 16 "ANILERIDINE"
                       17 "MORPHINE" 18 "METHADONE" 19 "STADOL" 20 "DARVOCET"
                       21 "LOMOTIL" 22 "PAREGORIC" 92 "OTHER" ;
label define AE4A3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "DARVON"
                       2 "DOLENE" 3 "SK-65" 4 "WYGESIC" 5 "LEVO-DROMORAN"
                       6 "PERCODAN" 7 "DEMEROL" 8 "DILAUDID"
                       9 "TYLENOL with CODEINE" 10 "PHENAPHEN with CODEINE"
                       11 "TALWIN" 12 "TALWIN NX" 13 "TALACEN"
                       14 "PROPOXYPHENE" 15 "CODEINE" 16 "ANILERIDINE"
                       17 "MORPHINE" 18 "METHADONE" 19 "STADOL" 20 "DARVOCET"
                       21 "LOMOTIL" 22 "PAREGORIC" 92 "OTHER" ;
label define AE4B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER USED NONMEDICALLY"
                       1 "1 OR 2 TIMES" 2 "3-5 TIMES" 3 "6-10 TIMES"
                       4 "11-49 TIMES" 5 "50-99 TIMES" 6 "100-199 TIMES"
                       7 "200+ TIMES" ;
label define AE5A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE5B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT USED AT ALL OVER THE PERIOD"
                       1 "LESS THAN ONCE/MONTH" 2 "1-3 TIMES PER MONTH"
                       3 "1-2 TIMES PER WEEK" 4 "3-4 TIMES PER WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AE5C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE5D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE5E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE5F3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE5G      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING, SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE5H3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE5I      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "IN A TX PROG" 2 "IN JAIL"
                       3 "STOPPED ON YOUR OWN" 4 "OTHER" ;
label define AE5J      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE5K      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEFORE ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE5K_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE5L      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEFORE ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE5L_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE5M      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE5N      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)"
                       12 "DRINKING" ;
label define AE5O      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE5P      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE5P_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE5Q      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE6A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AE6BS1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "BUTISOL"
                       2 "BUTICAPS" 3 "AMYTAL" 4 "MEBARAL" 5 "PLACIDYL"
                       6 "DORIDEN" 7 "NOLUDAR" 8 "NEMBUTAL" 9 "SECONAL"
                       10 "TUINAL" 11 "DALMANE" 12 "RESTORIL" 13 "HALCION"
                       14 "AMOBARBITAL" 15 "PHENOBARBITAL"
                       16 "METHAQUALONE (incl.SOPR,QUAALUDE)"
                       17 "CHLORAL HYDRATE" 18 "PENTOBARBITAL"
                       19 "SECOBARBITAL" 20 "FLURAZEPAN" 21 "NOCTEC"
                       92 "OTHER" ;
label define AE6BS2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "BUTISOL"
                       2 "BUTICAPS" 3 "AMYTAL" 4 "MEBARAL" 5 "PLACIDYL"
                       6 "DORIDEN" 7 "NOLUDAR" 8 "NEMBUTAL" 9 "SECONAL"
                       10 "TUINAL" 11 "DALMANE" 12 "RESTORIL" 13 "HALCION"
                       14 "AMOBARBITAL" 15 "PHENOBARBITAL"
                       16 "METHAQUALONE (incl.SOPR,QUAALUDE)"
                       17 "CHLORAL HYDRATE" 18 "PENTOBARBITAL"
                       19 "SECOBARBITAL" 20 "FLURAZEPAN" 21 "NOCTEC"
                       92 "OTHER" ;
label define AE6BS3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "BUTISOL"
                       2 "BUTICAPS" 3 "AMYTAL" 4 "MEBARAL" 5 "PLACIDYL"
                       6 "DORIDEN" 7 "NOLUDAR" 8 "NEMBUTAL" 9 "SECONAL"
                       10 "TUINAL" 11 "DALMANE" 12 "RESTORIL" 13 "HALCION"
                       14 "AMOBARBITAL" 15 "PHENOBARBITAL"
                       16 "METHAQUALONE (incl.SOPR,QUAALUDE)"
                       17 "CHLORAL HYDRATE" 18 "PENTOBARBITAL"
                       19 "SECOBARBITAL" 20 "FLURAZEPAN" 21 "NOCTEC"
                       92 "OTHER" ;
label define AE6BT1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "VALIUM"
                       2 "LIBRIUM" 3 "LIMBITROL" 4 "MENRIUM" 5 "SERAX"
                       6 "TRANXENE" 7 "ATIVAN" 8 "CENTRAX" 9 "XANAX"
                       10 "PAXIPAM" 11 "BUSPAR" 12 "MILTOWN" 13 "EQUANIL"
                       14 "DEPROL" 15 "VISARIL" 16 "ATARAX" 17 "DURRAX"
                       18 "DIAZEPAM" 19 "SK-LYGEN" 20 "MEPROBAMATE"
                       21 "HYDROXYZINE" 22 "BENADRYL" 23 "CLONAZEPAM"
                       24 "KLONOPIN" 92 "OTHER" ;
label define AE6BT2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "VALIUM"
                       2 "LIBRIUM" 3 "LIMBITROL" 4 "MENRIUM" 5 "SERAX"
                       6 "TRANXENE" 7 "ATIVAN" 8 "CENTRAX" 9 "XANAX"
                       10 "PAXIPAM" 11 "BUSPAR" 12 "MILTOWN" 13 "EQUANIL"
                       14 "DEPROL" 15 "VISARIL" 16 "ATARAX" 17 "DURRAX"
                       18 "DIAZEPAM" 19 "SK-LYGEN" 20 "MEPROBAMATE"
                       21 "HYDROXYZINE" 22 "BENADRYL" 23 "CLONAZEPAM"
                       24 "KLONOPIN" 92 "OTHER" ;
label define AE6BT3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VALIUM" 2 "LIBRIUM"
                       3 "LIMBITROL" 4 "MENRIUM" 5 "SERAX" 6 "TRANXENE"
                       7 "ATIVAN" 8 "CENTRAX" 9 "XANAX" 10 "PAXIPAM"
                       11 "BUSPAR" 12 "MILTOWN" 13 "EQUANIL" 14 "DEPROL"
                       15 "VISARIL" 16 "ATARAX" 17 "DURRAX" 18 "DIAZEPAM"
                       19 "SK-LYGEN" 20 "MEPROBAMATE" 21 "HYDROXYZINE"
                       22 "BENADRYL" 23 "CLONAZEPAM" 24 "KLONOPIN" ;
label define AE6C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER USED"
                       1 "1 OR 2 TIMES" 2 "3-5 TIMES" 3 "6-10 TIMES"
                       4 "11-49 TIMES" 5 "50-99 TIMES" 6 "100-199 TIMES"
                       7 "200+ TIMES" ;
label define AE7A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE7B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT USED AT ALL OVER THE PERIOD"
                       1 "LESS THAN ONCE/MONTH" 2 "1-3 TIMES PER MONTH"
                       3 "1-2 TIMES PER WEEK" 4 "3-4 TIMES PER WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AE7C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE7D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE7E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE7F3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE7G      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE7H3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE7I      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "IN A TX PROG" 2 "IN JAIL"
                       3 "STOPPED ON YOUR OWN" 4 "OTHER" ;
label define AE7J      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE7K      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE7K_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE7L      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE7L_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE7M      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE7N      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE7O71    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 71 "CIRCLED" ;
label define AE7O72    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 72 "CIRCLED" ;
label define AE7O73    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 73 "CIRCLED" ;
label define AE7O74    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 74 "CIRCLED" ;
label define AE7P      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       71 "SEDATIVES AND SLEEPING PILLS" 72 "BARBITURATES"
                       73 "BENZODIAZAPENES" 74 "OTHER TRANQUILIZERS" ;
label define AE8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE8A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE8B1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "DEXEDRINE"
                       2 "DEXAMYL" 3 "ESKATROL" 4 "BENZEDRINE"
                       5 "BIPHETAMINE" 6 "DESOXYN" 7 "TENUATE" 8 "TEPANIL"
                       9 "DIDREX" 10 "PLEGINE" 11 "PRELUDIN" 12 "IONAMIN"
                       13 "FASTIN" 14 "PONDIMIN" 15 "VORANIL" 16 "SANOREX"
                       17 "MAZANOR" 18 "RITALIN" 19 "CYLERT"
                       20 "DEXTROAMPHETAMINE" 21 "METHEDRINE"
                       22 "METHAMPHETAMINE" 23 "OBEDRIN-L.A." 92 "OTHER" ;
label define AE8B2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "DEXEDRINE"
                       2 "DEXAMYL" 3 "ESKATROL" 4 "BENZEDRINE"
                       5 "BIPHETAMINE" 6 "DESOXYN" 7 "TENUATE" 8 "TEPANIL"
                       9 "DIDREX" 10 "PLEGINE" 11 "PRELUDIN" 12 "IONAMIN"
                       13 "FASTIN" 14 "PONDIMIN" 15 "VORANIL" 16 "SANOREX"
                       17 "MAZANOR" 18 "RITALIN" 19 "CYLERT"
                       20 "DEXTROAMPHETAMINE" 21 "METHEDRINE"
                       22 "METHAMPHETAMINE (speed or crank)"
                       23 "OBEDRIN-L.A." ;
label define AE8B3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "DEXEDRINE"
                       2 "DEXAMYL" 3 "ESKATROL" 4 "BENZEDRINE"
                       5 "BIPHETAMINE" 6 "DESOXYN" 7 "TENUATE" 8 "TEPANIL"
                       9 "DIDREX" 10 "PLEGINE" 11 "PRELUDIN" 12 "IONAMIN"
                       13 "FASTIN" 14 "PONDIMIN" 15 "VORANIL" 16 "SANOREX"
                       17 "MAZANOR" 18 "RITALIN" 19 "CYLERT"
                       20 "DEXTROAMPHETAMINE" 21 "METHEDRINE"
                       22 "METHAMPHETAMINE (speed or crank)"
                       23 "OBEDRIN-L.A." ;
label define AE8C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER USED NONMEDICALLY"
                       1 "1 OR 2 TIMES" 2 "3-5 TIMES" 3 "6-10 TIMES"
                       4 "11-49 TIMES" 5 "50-99 TIMES" 6 "100-199 TIMES"
                       7 "200+ TIMES" ;
label define AE9A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE9B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT USED AT ALL OVER THE PERIOD"
                       1 "LESS THAN ONCE/MONTH" 2 "1-3 TIMES PER MONTH"
                       3 "1-2 TIMES PER WEEK" 4 "3-4 TIMES PER WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AE9C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE9D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE9E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE9F3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE9G      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE9H3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE9I      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "IN A TX PROG" 2 "IN JAIL"
                       3 "STOPPED ON YOUR OWN" 4 "OTHER" ;
label define AE9J      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE9K      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE9K_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE9L      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE9L_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE9M      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE9N      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE9O      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE9P      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE9P_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE9Q      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE9R      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEITHER"
                       1 "MAJOR TRANQUILIZERS" 2 "MAJOR ANTIDEPRESSANTS"
                       3 "BOTH" ;
label define AE10A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEITHER"
                       1 "MAJOR TRANQUILIZERS" 2 "MAJOR ANTIDEPRESSANTS"
                       3 "BOTH" ;
label define AE11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER USED"
                       1 "1 OR 2 TIMES" 2 "3-5 TIMES" 3 "6-10 TIMES"
                       4 "11-49 TIMES" 5 "50-99 TIMES" 6 "100-199 TIMES"
                       7 "200+ TIMES" ;
label define AE11A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE11B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT USED AT ALL OVER THE PERIOD"
                       1 "LESS THAN ONCE/MONTH" 2 "1-3 TIMES PER MONTH"
                       3 "1-2 TIMES PER WEEK" 4 "3-4 TIMES PER WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AE11C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE11D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE11E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE11F3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE11G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE11H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE11H_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE11I     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE11I_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE11J     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE11K     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE11L     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE11M     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE11M_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE11N     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE11O     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "1 OR 2 TIMES"
                       2 "3-5 TIMES" 3 "6-10 TIMES" 4 "11-49 TIMES"
                       5 "50-99 TIMES" 6 "100-199 TIMES" 7 "200+ TIMES" ;
label define AE12A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE12B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT USED AT ALL OVER THE PERIOD"
                       1 "LESS THAN ONCE/MONTH" 2 "1-3 TIMES PER MONTH"
                       3 "1-2 TIMES PER WEEK" 4 "3-4 TIMES PER WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AE12C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE12D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE12E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE12E_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE12F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE12F_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE12G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO FAVORITE DRUG"
                       10 "ALCOHOL" 20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS, SUCH AS L" 31 "PCP"
                       32 "HALLUCINOGENS OTHER THAN PCP"
                       40 "COCAINE IN ANY FORM" 41 "CRACK"
                       50 "HEROIN ALONE AND WITH OTHER DRUGS"
                       51 "HEROIN AND COCAINE TOGETHER AT THE SAME"
                       60 "NARCOTICS OR OPIATES SUCH AS MORPHINE, C"
                       61 "STREET OR ILLEGAL METHADONE"
                       62 "NARCOTICS OTHER THAN METHADONE"
                       70 "DOWNERS OR DEPRESSANTS SUCH AS SEDATIVES"
                       71 "SEDATIVES OR SLEEPING PILLS, SUCH AS DOR"
                       72 "BARBITURATES, SUCH AS NUMBUTAL, SECONAL,"
                       73 "BENZODIAZAPENES, SUCH AS VALIUM, LIBRIUM"
                       74 "OTHER TRANQUILIZERS" 75 "ANOTHER DEPRESSANT"
                       80 "AMPHETAMINES OR OTHER STIMULANTS, SPEED,"
                       81 "METHAMPHETAMINES OR ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS, SUCH AS GLUE, GASOLINE, PAINT"
                       92 "ANOTHER DRUG" ;
label define AE14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "DRUG USE DIDNT CAUSE PROB" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS, SUCH AS L" 31 "PCP"
                       32 "HALLUCINOGENS OTHER THAN PCP"
                       40 "COCAINE IN ANY FORM" 41 "CRACK"
                       50 "HEROIN ALONE AND WITH OTHER DRUGS"
                       51 "HEROIN AND COCAINE TOGETHER AT THE SAME"
                       60 "NARCOTICS OR OPIATES SUCH AS MORPHINE, C"
                       61 "STREET OR ILLEGAL METHADONE"
                       62 "NARCOTICS OTHER THAN METHADONE"
                       70 "DOWNERS OR DEPRESSANTS SUCH AS SEDATIVES"
                       71 "SEDATIVES OR SLEEPING PILLS, SUCH AS DOR"
                       72 "BARBITURATES, SUCH AS NUMBUTAL, SECONAL,"
                       73 "BENZODIAZAPENES, SUCH AS VALIUM, LIBRIUM"
                       74 "OTHER TRANQUILIZERS" 75 "ANOTHER DEPRESSANT"
                       80 "AMPHETAMINES OR OTHER STIMULANTS, SPEED,"
                       81 "METHAMPHETAMINES OR ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS, SUCH AS GLUE, GASOLINE, PAINT"
                       92 "ANOTHER DRUG" ;
label define AE14A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "1 OR 2 TIMES"
                       2 "3-5 TIMES" 3 "6-10 TIMES" 4 "11-49 TIMES"
                       5 "50-99 TIMES" 6 "100-199 TIMES" 7 "200+ TIMES" ;
label define AE14B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE14C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE14D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING (CRACK)" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE14E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE14E_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE14F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE14G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE14H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT USED AT ALL OVER THE PERIOD"
                       1 "LESS THAN ONCE/MONTH" 2 "1-3 TIMES PER MONTH"
                       3 "1-2 TIMES PER WEEK" 4 "3-4 TIMES PER WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AE15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE15A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS, SUCH AS L" 31 "PCP"
                       32 "HALLUCINOGENS OTHER THAN PCP"
                       40 "COCAINE IN ANY FORM" 41 "CRACK"
                       50 "HEROIN ALONE AND WITH OTHER DRUGS"
                       51 "HEROIN AND COCAINE TOGETHER AT THE SAME"
                       60 "NARCOTICS OR OPIATES SUCH AS MORPHINE, C"
                       61 "STREET OR ILLEGAL METHADONE"
                       62 "NARCOTICS OTHER THAN METHADONE"
                       70 "DOWNERS OR DEPRESSANTS SUCH AS SEDATIVES"
                       71 "SEDATIVES OR SLEEPING PILLS, SUCH AS DOR"
                       72 "BARBITURATES, SUCH AS NUMBUTAL, SECONAL,"
                       73 "BENZODIAZAPENES, SUCH AS VALIUM, LIBRIUM"
                       74 "OTHER TRANQUILIZERS" 75 "ANOTHER DEPRESSANT"
                       80 "AMPHETAMINES OR OTHER STIMULANTS, SPEED,"
                       81 "METHAMPHETAMINES OR ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS, SUCH AS GLUE, GASOLINE, PAINT"
                       92 "ANOTHER DRUG" ;
label define AE15B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "1-2 TIMES"
                       2 "3-5 TIMES" 3 "6-10 TIMES" 4 "11-49 TIMES"
                       5 "50-99 TIMES" 6 "100-199 TIMES" 7 "200+ TIMES" ;
label define AE15C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE15D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE15E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE15E_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE15F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE15G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE15H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT USED AT ALL OVER THE PERIOD"
                       1 "LESS THAN ONCE/MONTH" 2 "1-3 TIMES PER MONTH"
                       3 "1-2 TIMES PER WEEK" 4 "3-4 TIMES PER WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AE16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE16A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS OR PSYCHEDELICS, SUCH AS L" 31 "PCP"
                       32 "HALLUCINOGENS OTHER THAN PCP"
                       40 "COCAINE IN ANY FORM" 41 "CRACK"
                       50 "HEROIN ALONE AND WITH OTHER DRUGS"
                       51 "HEROIN AND COCAINE TOGETHER AT THE SAME"
                       60 "NARCOTICS OR OPIATES SUCH AS MORPHINE, C"
                       61 "STREET OR ILLEGAL METHADONE"
                       62 "NARCOTICS OTHER THAN METHADONE"
                       70 "DOWNERS OR DEPRESSANTS SUCH AS SEDATIVES"
                       71 "SEDATIVES OR SLEEPING PILLS, SUCH AS DOR"
                       72 "BARBITURATES, SUCH AS NUMBUTAL, SECONAL,"
                       73 "BENZODIAZAPENES, SUCH AS VALIUM, LIBRIUM"
                       74 "OTHER TRANQUILIZERS" 75 "ANOTHER DEPRESSANT"
                       80 "AMPHETAMINES OR OTHER STIMULANTS, SPEED,"
                       81 "METHAMPHETAMINES OR ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS, SUCH AS GLUE, GASOLINE, PAINT"
                       92 "ANOTHER DRUG" ;
label define AE16B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "1 OR 2 TIMES"
                       2 "3-5 TIMES" 3 "6-10 TIMES" 4 "11-49 TIMES"
                       5 "50-99 TIMES" 6 "100-199 TIMES" 7 "200+ TIMES" ;
label define AE16C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE16D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE16E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE16E_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE16F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "LESS THAN ONCE/MONTH"
                       2 "1-3 TIMES/MONTH" 3 "1-2 TIMES/WEEK"
                       4 "3-4 TIMES/WEEK" 5 "5-6 TIMES/WEEK"
                       6 "DAILY OR ALMOST EVERY DAY" 7 "2-3 TIMES/DAY"
                       8 "4+ TIMES/DAY" ;
label define AE16G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY MOUTH (EAT,CHEW)"
                       2 "SMOKING" 3 "INHALING, SNORTING OR SNIFFING"
                       4 "INJECTING INTO VEIN" 5 "INJECTING SOMEWHERE ELSE"
                       6 "FREEBASING" 7 "SOME OTHER WAY (SPECIFY)" ;
label define AE16H     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NOT USED AT ALL OVER THE PERIOD"
                       1 "LESS THAN ONCE/MONTH" 2 "1-3 TIMES PER MONTH"
                       3 "1-2 TIMES PER WEEK" 4 "3-4 TIMES PER WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AE17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "BY YOURSELF"
                       2 "WITH 1 OR 2 OTHER PEOPLE" 3 "IN A GROUP" ;
label define AE18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "AT HOME"
                       2 "AT FRIENDS OR RELATIVES HOME"
                       3 "AT SHOOTING GALLERY" 4 "ON THE STREET"
                       5 "IN A MOTOR VEHICLE" 6 "SOME OTHER PLACE" ;
label define AE19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE19A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AE19B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "4+" ;
label define AE19C1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS/PSYCHEDELICS" 31 "PCP"
                       32 "HALLUCINOGENS OTHER THAN PCP"
                       40 "COCAINE IN ANY FORM" 41 "CRACK"
                       50 "HEROIN ALONE,WITH OTHER DRUGS"
                       51 "HEROIN/COCAINE TOGETHER AT SAME TIME"
                       60 "NARCOTICS/OPIATES" 61 "STREET/ILLEGAL METHADONE"
                       62 "NARCOTICS OTHER THAN METHADONE"
                       70 "DOWNERS/DEPRESSANTS" 71 "SEDATIVES/SLEEPING PILLS"
                       72 "BARBITURATES" 73 "BENZODIAZAPENES"
                       74 "OTHER TRANQUILIZERS" 75 "ANOTHER DEPRESSANT"
                       80 "AMPHETAMINES/OTHER STIMULANTS/SPEED"
                       81 "METHAMPHETAMINES/ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" 92 "ANOTHER DRUG" ;
label define AE19C2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS/PSYCHEDELICS" 31 "PCP"
                       32 "HALLUCINOGENS OTHER THAN PCP"
                       40 "COCAINE IN ANY FORM" 41 "CRACK"
                       50 "HEROIN ALONE,WITH OTHER DRUGS"
                       51 "HEROIN/COCAINE TOGETHER AT SAME TIME"
                       60 "NARCOTICS/OPIATES" 61 "STREET/ILLEGAL METHADONE"
                       62 "NARCOTICS OTHER THAN METHADONE"
                       70 "DOWNERS/DEPRESSANTS" 71 "SEDATIVES/SLEEPING PILLS"
                       72 "BARBITURATES" 73 "BENZODIAZAPENES"
                       74 "OTHER TRANQUILIZERS" 75 "ANOTHER DEPRESSANT"
                       80 "AMPHETAMINES/OTHER STIMULANTS/SPEED"
                       81 "METHAMPHETAMINES/ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" 92 "ANOTHER DRUG" ;
label define AE19C3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 10 "ALCOHOL"
                       20 "MARIJUANA, HASHISH, THC"
                       30 "HALLUCINOGENS/PSYCHEDELICS" 31 "PCP"
                       32 "HALLUCINOGENS OTHER THAN PCP"
                       40 "COCAINE IN ANY FORM" 41 "CRACK"
                       50 "HEROIN ALONE,WITH OTHER DRUGS"
                       51 "HEROIN/COCAINE TOGETHER AT SAME TIME"
                       60 "NARCOTICS/OPIATES" 61 "STREET/ILLEGAL METHADONE"
                       62 "NARCOTICS OTHER THAN METHADONE"
                       70 "DOWNERS/DEPRESSANTS" 71 "SEDATIVES/SLEEPING PILLS"
                       72 "BARBITURATES" 73 "BENZODIAZAPENES"
                       74 "OTHER TRANQUILIZERS" 75 "ANOTHER DEPRESSANT"
                       80 "AMPHETAMINES/OTHER STIMULANTS/SPEED"
                       81 "METHAMPHETAMINES/ICE" 90 "ANY OTHER DRUGS"
                       91 "INHALANTS" 92 "ANOTHER DRUG" ;
label define AE20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE21A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE22      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE22A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE22B1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AE22B2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AE22B3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AE22B4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AE22B5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AE22B6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AE23      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE24A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define AE24B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define AE24C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define AE24D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define AE24E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define AE24F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "RARELY"
                       2 "SOMETIMES" 3 "OFTEN" 4 "ALWAYS" ;
label define AE25      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE25A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE26A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE26AA    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE26AB    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AE26AC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26AD1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define AE26AD2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26AE    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "COMPLETED TX"
                       2 "DISCHARGED BY STAFF"
                       3 "TRANSFERRED TO COMPONENT OF SAME PROG"
                       4 "TRANSFERRED TO ANOTHER SOCIAL SERVICE"
                       5 "INVOLUNTARILY DISCHARGED"
                       6 "VOLUNTARILY DROPPED OUT"
                       7 "QUIT BECAUSE OF DISSATISFACTION" 8 "OTHER" ;
label define AE26B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE26BA    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE26BB    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26BC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26BD1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define AE26BD2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26BE    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "COMPLETED TX"
                       2 "DISCHARGED BY STAFF"
                       3 "TRANSFERRED TO COMPONENT OF SAME PROG"
                       4 "TRANSFERRED TO ANOTHER SOCIAL SERVICE"
                       5 "INVOLUNTARILY DISCHARGED"
                       6 "VOLUNTARILY DROPPED OUT"
                       7 "QUIT BECAUSE OF DISSATISFACTION" 8 "OTHER" ;
label define AE26C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE26CA    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE26CB    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26CC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AE26CD1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define AE26CD2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26CE    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "COMPLETED TX"
                       2 "DISCHARGED BY STAFF"
                       3 "TRANSFERRED TO COMPONENT OF SAME PROG"
                       4 "TRANSFERRED TO ANOTHER SOCIAL SERVICE"
                       5 "INVOLUNTARILY DISCHARGED"
                       6 "VOLUNTARILY DROPPED OUT"
                       7 "QUIT BECAUSE OF DISSATISFACTION" 8 "OTHER" ;
label define AE26D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE26DA    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE26DB    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26DC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26DD1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define AE26DD2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26DE    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "COMPLETED TX"
                       2 "DISCHARGED BY STAFF"
                       3 "TRANSFERRED TO COMPONENT OF SAME PROG"
                       4 "TRANSFERRED TO ANOTHER SOCIAL SERVICE"
                       5 "INVOLUNTARILY DISCHARGED"
                       6 "VOLUNTARILY DROPPED OUT"
                       7 "QUIT BECAUSE OF DISSATISFACTION" 8 "OTHER" ;
label define AE26E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE26EA    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE26EB    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26EC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26ED1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define AE26ED2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26EE    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "COMPLETED TX"
                       2 "DISCHARGED BY STAFF"
                       3 "TRANSFERRED TO COMPONENT OF SAME PROG"
                       4 "TRANSFERRED TO ANOTHER SOCIAL SERVICE"
                       5 "INVOLUNTARILY DISCHARGED"
                       6 "VOLUNTARILY DROPPED OUT"
                       7 "QUIT BECAUSE OF DISSATISFACTION" 8 "OTHER" ;
label define AE26F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE26FA    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AE26FB    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AE26FC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26FD1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "JAN.-MARCH" 2 "APR.-JUNE"
                       3 "JULY-SEPT." 4 "OCT.-DEC." ;
label define AE26FD2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE26FE    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "COMPLETED TX"
                       2 "DISCHARGED BY STAFF"
                       3 "TRANSFERRED TO COMPONENT OF SAME PROG"
                       4 "TRANSFERRED TO ANOTHER SOCIAL SERVICE"
                       5 "INVOLUNTARILY DISCHARGED"
                       6 "VOLUNTARILY DROPPED OUT"
                       7 "QUIT BECAUSE OF DISSATISFACTION" 8 "OTHER" ;
label define AE27_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE28      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SHORT-TERM INPATIENT"
                       2 "LONG-TERM RESIDENTIAL COMMUNITY" 3 "METHADONE"
                       4 "OUTPATIENT" 5 "OTHER (SPECIFY)" 6 "DETOXIFICATION"
                       7 "STILL IN LONG-TERM MAINTENANCE" ;
label define AE29      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "COMPLETED TX"
                       2 "DISCHARGED BY STAFF"
                       3 "TRANSFERRED TO COMPONENT OF SAME PROG"
                       4 "TRANSFERRED TO ANOTHER SOCIAL SERVICE"
                       5 "INVOLUNTARILY DISCHARGED"
                       6 "VOLUNTARILY DROPPED OUT"
                       7 "QUIT BECAUSE OF DISSATISFACTION"
                       8 "OTHER (SPECIFY)" ;
label define AE30      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE30_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE31      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE31A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE31A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE32      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE32A3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE32B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AE32B_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AE33      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE33AA    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" ;
label define AE33BA    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALCOHOL" 2 "DRUG"
                       3 "BOTH" ;
label define AE33CA    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE33AB    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" ;
label define AE33BB    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALCOHOL" 2 "DRUG"
                       3 "BOTH" ;
label define AE33CB    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE33AC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" ;
label define AE33BC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALCOHOL" 2 "DRUG"
                       3 "BOTH" ;
label define AE33CC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE33AD    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" ;
label define AE33BD    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALCOHOL" 2 "DRUG"
                       3 "BOTH" ;
label define AE33CD    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AE33AE    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" ;
label define AE33BE    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALCOHOL" 2 "DRUG"
                       3 "BOTH" ;
label define AE33CE    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF1A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF1B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF1C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALL" 2 "SOME" 3 "NONE" ;
label define AF1D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AF1E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AF1E_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF2A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF2B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF2C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF2D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALL" 2 "SOME" 3 "NONE" ;
label define AF2E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AF2F      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF2G      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF2H      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AF2H_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF3A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AF3A_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF3B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF4A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF4B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AF4B_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF4C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF5A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALL" 2 "SOME" 3 "NONE" ;
label define AF5B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AF5B_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF6A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF6B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF6C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AF6C_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF7A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALL" 2 "SOME" 3 "NONE" ;
label define AF7B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AF7B_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF8A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF12A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AF13A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF13B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF13C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF13D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF13E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF13F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AF14A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AF15_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF15A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "COMMUNITY MENTAL HEALTH CENTER"
                       2 "PRIV PSYCHIATRIC HOSPITAL"
                       3 "PUB/STATE PSYCHIATRIC HOSPITAL"
                       4 "ANY OTHER HOSPITAL"
                       5 "EMERGENCY ROOM OR CRISIS CENTER"
                       6 "ANY OTHER PLACE FOR EMOTIONAL PROBS" ;
label define AF16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF17A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF17B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF17C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF17D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF17E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF17F     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF17G     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AF18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AF18A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AF19_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AF20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "COMMUNITY MENTAL HEALTH CENTER" 2 "PRIV THERAPIST"
                       3 "FAMILY PHYSICIAN OR OTHER DOCTOR"
                       4 "PRIV PSYCHIATRIC HOSPITAL"
                       5 "PUB/STATE PSYCHIATRIC HOSPITAL"
                       6 "ANY OTHER HOSPITAL" 7 "ANYWHERE ELSE" ;
label define AF21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY TROUBLED" ;
label define AF22      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF22A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY SERIOUS" ;
label define AF23      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY TROUBLED" ;
label define AF24      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF24AA    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" ;
label define AF24BA    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF24AB    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" ;
label define AF24BB    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF24AC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" ;
label define AF24BC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF24AD    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" ;
label define AF24BD    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AF24AE    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" ;
label define AF24BE    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "1-3 TICKETS"
                       2 "4-5 TICKETS" 3 "6-10 TICKETS" 4 "11-49 TICKETS"
                       5 "50-99 TICKETS" 6 "100-199 TICKETS" 7 "200 OR MORE" ;
label define AG1A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AG1B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AG1B_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG1C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "1-2 TIMES"
                       2 "3-5 TIMES" 3 "6-10 TIMES" 4 "11-49 TIMES"
                       5 "50-99 TIMES" 6 "100-199 TIMES" 7 "200+ TIMES" ;
label define AG1D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "1-2 TIMES"
                       2 "3-5 TIMES" 3 "6-10 TIMES" 4 "11-49 TIMES"
                       5 "50-99 TIMES" 6 "100-199 TIMES" 7 "200+ TIMES" ;
label define AG3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AG4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AG4A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AG6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER" 1 "1 OR 2 TIMES"
                       2 "3-5 TIMES" 3 "6-10 TIMES" 4 "11-49 TIMES"
                       5 "50-99 TIMES" 6 "100-199 TIMES" 7 "200+ TIMES" ;
label define AG6A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AG6B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AG6B_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG7_1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG8_1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG9_1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG7_2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG8_2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AG9_2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG7_3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG8_3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG9_3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG7_4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG8_4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG9_4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG7_5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG8_5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AG9_5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG7_6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG8_6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AG9_6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG7_7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG8_7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG9_7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG7_8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG8_8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG9_8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG7_9     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG8_9     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG9_9     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG7_10    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG8_10    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG9_10    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG7_11    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG8_11    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AG9_11    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG13A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AG13B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AG13B_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG14A3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG14B3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG14C3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "USE/POSSESSION OF MARIJUANA"
                       2 "USE/POSSESSION OF NARCOTICS"
                       3 "SALE/MANUFACTURE OF NARCOTICS"
                       4 "FORGERY/FRAUD/EMBEZZLEMENT"
                       5 "BUYING/RECEIVING/POSSESSION OF STOLEN"
                       6 "GAMBLING (INCLUDING NUMBERS AND BOOKMAKI"
                       7 "PIMPING/PROSTITUTION/COMMERCIAL VICE"
                       8 "BURGLARY-B & E/UNLAWFUL ENTRY/HOUSEBR"
                       9 "LARCENY-THEFT"
                       10 "ROBBERY-BANK/MUGGING/ARMED ROBBERY"
                       11 "ATTACKS ON PERSONS SUCH AS HOMICIDES"
                       12 "OTHER OFFENSES WHERE PEOPLE MAY BE INJUR"
                       13 "WEAPONS OFFENSES"
                       14 "VAGRANCY/SUSPICION/DISORDERLY CONDUCT,"
                       15 "LIQUOR LAW VIOLATIONS/DRUNK & DISORDERL"
                       16 "PROBATION/PAROLE VIOLATIONS"
                       17 "CONTEMPT OF COURT" ;
label define AG15A3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG15B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AG15B_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG15C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG15D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY TROUBLED" ;
label define AG17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY IMPORTANT" ;
label define AG18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG18A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY SERIOUS" ;
label define AG19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG19A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AG20A3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG20B1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define AG20B2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define AG20B3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define AG20B4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define AG20B5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define AG20B6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define AG20B7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define AG20C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AG20C_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AG21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE"
                       1 "LESS THAN ONCE/MONHT" 2 "1-3 TIMES/MONTH"
                       3 "1-2 TIMES/WEEK" 4 "3-4 TIMES/WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define AH1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "WORKING AT A LEGITIMATE JOB"
                       2 "HAD JOB BUT NOT WORKING" 3 "LOOKING FOR WORK"
                       4 "KEEPING HOUSE FOR SELF" 5 "SCHOOL OR TRAINING PROG"
                       6 "UNABLE TO WORK, DISABLED" 7 "RETIRED"
                       8 "IN JAIL, RESIDENTIAL TX PROG"
                       9 "INVOLVED IN DRUG-RELATED ACTIVITIES"
                       10 "INVOLVED IN OTHER ILLEGAL ACTIVITIES"
                       11 "NOT WORKING AND NOT INTERESTED IN WORK"
                       12 "OTHER (SPECIFY)" 13 "WAITING TO GO INTO TX"
                       14 "LAID OFF" 15 "TERMINATED"
                       16 "LOOKING FOR APARTMENT" 17 "TRAVELING"
                       18 "IN HOSPITAL" 19 "RELEASED FROM HALFWAY HOUSE"
                       20 "DRINKING/GETTING HIGH" 21 "ON GENERAL ASSISTANCE"
                       22 "JUST LIVING OR SURVIVING" 23 "PROSTITUTING"
                       24 "GOING TO OUTPT MTGS (NA/AA)"
                       25 "TRYING TO GET CHILD BACK" 26 "COMMUNITY SERVICE"
                       27 "GOING TO COURT" 28 "WOMENS SHELTER"
                       29 "IN HIDING/FROM WARRANTS" 30 "APPLY FOR SSI"
                       31 "APPLYING FOR GETTING MARRIED" 32 "SLEEPING"
                       33 "HOMELESS" 34 "WORK RELEASE" 35 "GOING TO CHURCH"
                       36 "RELEASED FROM JAIL" 37 "PUB ASSISTANCE"
                       38 "VOLUNTEER SERVICE" 39 "UNDER HOUSE ARREST"
                       40 "OTHER" ;
label define AH2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH2A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "DID NOT EARN MONEY LEGALLY"
                       2 "DID EARN MONEY LEGALLY" ;
label define AH2B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH2C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AH2D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 99 "99 OR MORE" ;
label define AH2E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "SLACK WORK, LAYOFFS, STRIKE" 2 "SEASONAL WORKER"
                       3 "JOB TERMINATED DURING WEEK"
                       4 "NEW JOB STARTED DURING WEEK"
                       5 "COULD ONLY FIND PART-TIME WORK"
                       6 "DRUG OR ALCOHOL PROB" 7 "ILLNESS" 8 "VACATION"
                       9 "BUSY W/OTHER ACTIVITIES"
                       10 "DIDNT WANT/NEED FULL-TIME WORK"
                       11 "WORK WEEK USUALLY UNDER 35 HRS"
                       12 "UNABLE TO WORK" 13 "RETIRED"
                       14 "IN JAIL, RESIDENTIAL TX PROG"
                       15 "INVOLVED IN ILLEGAL ACTIVITIES"
                       16 "OTHER (SPECIFY)" ;
label define AH2F      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH2G      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "SLACK WORK, LAYOFFS, STRIKE" 2 "SEASONAL WORKER"
                       3 "JOB TERMINATED DURING WEEK"
                       4 "NEW JOB STARTED DURING WEEK"
                       5 "COULD ONLY FIND PART-TIME WORK"
                       6 "DRUG OR ALCOHOL PROB" 7 "ILLNESS" 8 "VACATION"
                       9 "BUSY W/OTHER ACTIVITIES"
                       10 "DIDNT WANT/NEED FULL-TIME WORK"
                       11 "WORK WEEK USUALLY UNDER 35 HRS"
                       12 "UNABLE TO WORK" 13 "RETIRED"
                       14 "IN JAIL, RESIDENTIAL TX PROG"
                       15 "INVOLVED IN ILLEGAL ACTIVITIES"
                       16 "OTHER (SPECIFY)" ;
label define AH3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH3_01    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define AH3_02    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define AH3_03    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define AH3_04    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define AH3_05    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define AH3_06    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define AH3_07    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define AH3B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH3C1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define AH3C2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define AH3C4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define AH3C5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define AH3C6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define AH3C7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define AH3C8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define AH3C10    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 10 "CIRCLED" ;
label define AH3C11    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define AH3D1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "CIRCLED" ;
label define AH3D2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define AH3D3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define AH3D4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define AH3D5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define AH3D6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define AH3D7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define AH3D8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 7 "CIRCLED" ;
label define AH3D9     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 8 "CIRCLED" ;
label define AH3D10    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 9 "CIRCLED" ;
label define AH3D11    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 10 "CIRCLED" ;
label define AH3D12    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 11 "CIRCLED" ;
label define AH3D13    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 12 "CIRCLED" ;
label define AH3D14    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 13 "CIRCLED" ;
label define AH3D15    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 14 "CIRCLED" ;
label define AH3D16    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 15 "CIRCLED" ;
label define AH3D17    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 16 "CIRCLED" ;
label define AH4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH4A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO DIAGNOSIS"
                       1 "SUBSTANCE-RELATED CONDITIONS"
                       2 "MENTAL HEALTH CONDITIONS" 3 "ALL OTHER CONDITIONS" ;
label define AH4A2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO DIAGNOSIS"
                       1 "SUBSTANCE-RELATED CONDITIONS"
                       2 "MENTAL HEALTH CONDITIONS" 3 "ALL OTHER CONDITIONS" ;
label define AH4A3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO DIAGNOSIS"
                       1 "SUBSTANCE-RELATED CONDITIONS"
                       2 "MENTAL HEALTH CONDITIONS" 3 "ALL OTHER CONDITIONS" ;
label define AH4B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "SLIGHTLY" 2 "MODERATELY"
                       3 "SEVERELY" 4 "VERY SEVERELY" ;
label define AH4C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "GET BETTER"
                       1 "STAY ABOUT THE SAME" 2 "STAY THE SAME IF CAREFUL"
                       3 "SLOWLY GET WORSE IN TIME"
                       4 "MAY GET MUCH WORSE IN FUTURE" ;
label define AH4D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "ALMOST IMPOSSIBLE"
                       2 "VERY DIFFICULT" 3 "A LITTLE DIFFICULT"
                       4 "NOT DIFFICULT" ;
label define AH5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVES" 7 "TRANSPORTATION EQUIPMENT OPERATIVES"
                       8 "LABORERS (FARM & NONFARM)" 10 "SERVICE WORKER"
                       86 "OTHER" ;
label define AH9A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "AGRICULTURE/FORESTRY/FISHERIES" 2 "CONSTRUCTION"
                       3 "MANUFACTURING"
                       4 "TRANSPORT./COMMUNIC./OTHER PUB UTILITIES"
                       5 "WHOLESALE TRADE" 6 "RETAIL TRADE"
                       7 "FINANCE/INSUR./REAL ESTATE"
                       8 "BUSINESS/REPAIR SERVICES" 9 "PERSONAL SERVICES"
                       10 "ENTERTAINMENT/REC. SVCS" 11 "PROF./RELATED SVCS"
                       12 "PUB ADMIN." 13 "INDUSTRY NOT REPORTED" ;
label define AH9B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       4 "NO-USUALLY CLERICAL" 5 "NO-USUALLY CRAFT/KINDRED"
                       10 "NO-USUALLY SVC WKR" ;
label define AH9B1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVES" 7 "TRANSPORTATION EQUIPMENT OPERATIVES"
                       8 "LABORERS (FARM & NONFARM)" 10 "SERVICE WORKER"
                       86 "OTHER" ;
label define AH9C1     -9.00 "LEGITIMATE SKIP" -8.00 "BLANK" -7.00 "REFUSAL"
                       -6.00 "MULTIPLE RESPONSE" -5.00 "BAD DATA"
                       -4.00 "DON'T KNOW" -3.00 "NOT APPLICABLE"
                       -2.00 "ILLEGIBLE" -1.00 "VARIABLE NOT ON FORM" ;
label define AH9C2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "HOUR" 2 "WEEK" 3 "2 WKS"
                       4 "MONTH" 5 "YR" 6 "OTHER" ;
label define AH9D3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH9E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       0 "NEVER HAD A FULL TIME JOB" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AH10_M    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH10A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVES" 7 "TRANSPORTATION EQUIPMENT OPERATIVES"
                       8 "LABORERS (FARM & NONFARM)" 10 "SERVICE WORKER"
                       86 "OTHER" ;
label define AH10B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "AGRICULTURE/FORESTRY/FISHERIES" 2 "CONSTRUCTION"
                       3 "MANUFACTURING"
                       4 "TRANSPORT./COMMUNIC./OTHER PUB UTILITIES"
                       5 "WHOLESALE TRADE" 6 "RETAIL TRADE"
                       7 "FINANCE/INSUR./REAL ESTATE"
                       8 "BUSINESS/REPAIR SERVICES" 9 "PERSONAL SERVICES"
                       10 "ENTERTAINMENT/REC. SVCS" 11 "PROF./RELATED SVCS"
                       12 "PUB ADMIN." 13 "INDUSTRY NOT REPORTED" ;
label define AH10C1    -9.00 "LEGITIMATE SKIP" -8.00 "BLANK" -7.00 "REFUSAL"
                       -6.00 "MULTIPLE RESPONSE" -5.00 "BAD DATA"
                       -4.00 "DON'T KNOW" -3.00 "NOT APPLICABLE"
                       -2.00 "ILLEGIBLE" -1.00 "VARIABLE NOT ON FORM" ;
label define AH10C2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "HOUR" 2 "WEEK" 3 "2 WKS"
                       4 "MONTH" 5 "YR" 6 "OTHER" ;
label define AH10D3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH10E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH11_3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH11A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AH11A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH11B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "PROFESSIONAL AND TECHNICAL"
                       2 "MANAGER AND ADMINISTRATOR" 3 "SALES"
                       4 "CLERICAL OR OFFICE WORKER" 5 "CRAFT AND KINDRED"
                       6 "OPERATIVES" 7 "TRANSPORTATION EQUIPMENT OPERATIVES"
                       8 "LABORERS (FARM & NONFARM)" 10 "SERVICE WORKER"
                       86 "OTHER" ;
label define AH11C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM"
                       1 "AGRICULTURE/FORESTRY/FISHERIES" 2 "CONSTRUCTION"
                       3 "MANUFACTURING"
                       4 "TRANSPORT./COMMUNIC./OTHER PUB UTILITIES"
                       5 "WHOLESALE TRADE" 6 "RETAIL TRADE"
                       7 "FINANCE/INSUR./REAL ESTATE"
                       8 "BUSINESS/REPAIR SERVICES" 9 "PERSONAL SERVICES"
                       10 "ENTERTAINMENT/REC. SVCS" 11 "PROF./RELATED SVCS"
                       12 "PUB ADMIN." 13 "INDUSTRY NOT REPORTED" ;
label define AH11D1    -9.0000 "LEGITIMATE SKIP" -8.0000 "BLANK"
                       -7.0000 "REFUSAL" -6.0000 "MULTIPLE RESPONSE"
                       -5.0000 "BAD DATA" -4.0000 "DON'T KNOW"
                       -3.0000 "NOT APPLICABLE" -2.0000 "ILLEGIBLE"
                       -1.0000 "VARIABLE NOT ON FORM" ;
label define AH11D2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "HOUR" 2 "WEEK" 3 "2 WKS"
                       4 "MONTH" 5 "YR" 6 "OTHER" ;
label define AH12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY POORLY"
                       2 "SOMEWHAT POORLY" 3 "A LITTLE LESS THAN AVERAGE"
                       4 "WELL OR VERY WELL" ;
label define AH13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "VERY POORLY"
                       2 "SOMEWHAT POORLY" 3 "A LITTLE LESS THAN AVERAGE"
                       4 "WELL OR VERY WELL" ;
label define AH14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "NEVER HAD A JOB" ;
label define AH14A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH15A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AH15B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AH15B_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH16A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AH16B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AH16B_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH17A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH17B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "PHYSICAL ILLNESS/INJURY"
                       2 "MEDICATION/DRUG/ALCOHOL"
                       3 "NERVES, ANXIETY, STRESS, DEPRESSION"
                       4 "NO DEFINITE DIAGNOSIS" ;
label define AH17C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH17D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH17E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH18A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH18B3    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NO, LESS THAN 6 MOS"
                       2 "YES, 6 MOS OR MORE" ;
label define AH19A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AH19A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AH20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define AH21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define AH22      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AH22A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY MUCH" ;
label define AJ1A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AJ2A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ1B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AJ2B      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ1C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AJ2C      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ1D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AJ2D      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ1E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AJ2E      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ1F      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AJ2F      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ2_TOT   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO INCOME" 1 "$1-1,999"
                       2 "2,000-2,999" 3 "3,000-3,999" 4 "4,000-4,999"
                       5 "5,000-5,999" 6 "6,000-6,999" 7 "7,000-7,999"
                       8 "8,000-8,999" 9 "9,000-9,999" 10 "10,000-11,999"
                       12 "12,000-13,999" 14 "14,000-15,999"
                       16 "16,000-17,999" 18 "18,000-19,999"
                       20 "20,000-23,999" 24 "24,000-29,999"
                       30 "30,000-39,999" 40 "40,000-49,999"
                       50 "50,000-99,999" 100 "100,000 or more" ;
label define AJ4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AJ5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AJ5A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO INCOME" 1 "$1-1,999"
                       2 "2,000-2,999" 3 "3,000-3,999" 4 "4,000-4,999"
                       5 "5,000-5,999" 6 "6,000-6,999" 7 "7,000-7,999"
                       8 "8,000-8,999" 9 "9,000-9,999" 10 "10,000-11,999"
                       12 "12,000-13,999" 14 "14,000-15,999"
                       16 "16,000-17,999" 18 "18,000-19,999"
                       20 "20,000-23,999" 24 "24,000-29,999"
                       30 "30,000-39,999" 40 "40,000-49,999"
                       50 "50,000-99,999" 100 "100,000 or more" ;
label define AJ7A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ7A2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MONTH" 2 "YR" ;
label define AJ7B1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ7B2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MONTH" 2 "YR" ;
label define AJ7C1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ7C2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MONTH" 2 "YR" ;
label define AJ7D1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ7D2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MONTH" 2 "YR" ;
label define AJ8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define AJ10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AJ10A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "NOT AT ALL" 2 "SOMEWHAT"
                       3 "VERY MUCH" ;
label define AJ11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT AT ALL" 1 "SOMEWHAT"
                       2 "VERY MUCH" ;
label define AJ12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AJ12A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "WITHIN MONTH BEF ADM"
                       2 "WITHIN PAST 12 MOS" 3 "MORE THAN 1 YR AGO" ;
label define AJ12A_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AJ12B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO"
                       3 "FELT BAD ABOUT SOME, NOT OTHERS" ;
label define AJ13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AJ14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AJ14A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AJ14B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK12A1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK12B1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK12B1_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK12A2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK12B2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK12B2_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK12A4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK12B4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK12B4_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK12A5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK12B5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK12B5_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK12A6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK12B6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK12B6_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK12A7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK12B7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK12B7_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK12A8    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK12B8    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK12B8_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK3A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK3B1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK3B1_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK3A2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK3B2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK3B2_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK3A4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK3B4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK3B4_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK3A5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK3B5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK3B5_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK3A6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK3B6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK3B6_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK3A7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK3B7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK3B7_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK3A8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK3B8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK3B8_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK4A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK4B1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK4B1_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK4A2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK4B2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK4B2_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK4A4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK4B4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK4B4_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK4A5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK4B5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK4B5_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK4A6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK4B6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK4B6_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK4A7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK4B7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK4B7_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK4A8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK4B8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK4B8_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK56A1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK56B1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK56B1_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK56A2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK56B2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK56B2_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK56A4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK56B4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK56B4_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK56A5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK56B5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK56B5_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK56A6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK56B6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK56B6_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK56A7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK56B7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK56B7_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK56A8    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK56B8    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK56B8_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK78A1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK78B1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK78B1_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK78A2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK78B2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK78B2_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK78A4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK78B4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK78B4_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK78A5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK78B5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK78B5_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK78A6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK78B6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK78B6_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK78A7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK78B7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK78B7_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK78A8    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK78B8    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK78B8_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK9A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK9B1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK9B1_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK9A2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK9B2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK9B2_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK9A4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK9B4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK9B4_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK9A5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK9B5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK9B5_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK9A6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK9B6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK9B6_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK9A7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK9B7     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK9B7_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK9A8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK9B8     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK9B8_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK10      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK10A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK10B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK10C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITH THE PAST YR"
                       3 "MORE THAN 1 YR AGO" ;
label define AK10C_M   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK11      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK12      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_1A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_1B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_1C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_1D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK13_1DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK13_3A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_3B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_3C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_3D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK13_3DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK13_4A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_4B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_4C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_4D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK13_4DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK13_5A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_5B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_5C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_5D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK13_5DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK13_6A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_6B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_6C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_6D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK13_6DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK13_7A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_7B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_7C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK13_7D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK13_7DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK14      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_1A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_1B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_1C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK14_1CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK14_2A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_2B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_2C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK14_2CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK14_4A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_4B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_4C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK14_4CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK14_5A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_5B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_5C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK14_5CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK14_6A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_6B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_6C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK14_6CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK14_7A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_7B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_7C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK14_7CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK14_8A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_8B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK14_8C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK14_8CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK15      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_1A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_1B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_1C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_1D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK15_1DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK15_2A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_2B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_2C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_2D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN THE PAST 12 MNTHS"
                       3 "MORE THAN 1 YR" ;
label define AK15_2DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK15_4A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_4B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_4C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_4D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK15_4DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK15_5A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_5B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_5C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_5D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK15_5DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK15_6A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_6B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_6C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_6D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK15_6DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK15_7A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_7B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_7C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_7D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK15_7DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK15_8A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_8B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_8C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK15_8D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK15_8DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK16A1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK16B1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK16B1_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK16A2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK16B2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK16B2_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK16A4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK16B4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK16B4_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK16A5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK16B5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK16B5_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK16A6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK16B6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK16A7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK16B7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK16B7_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK16A8    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK16B8    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK16B8_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK17A1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK17B1    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK17B1_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK17A2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK17B2    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK17B2_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK17A4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK17B4    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK17B4_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK17A5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK17B5    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK17B5_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK17A6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK17B6    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK17B6_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK17A7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK17B7    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK17B7_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK17A8    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK17B8    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK17B8_M  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK18      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK18A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AK18B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK18C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_1A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_1B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_1C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_1D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN THE PAST 12 MNTHS"
                       3 "MORE THAN 1 YR" ;
label define AK19_1DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK19_3A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_3B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_3C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_3D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK19_3DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK19_4A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_4B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_4C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_4D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK19_4DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK19_5A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_5B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_5C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_5D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK19_5DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK19_6A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_6B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_6C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_6D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK19_6DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK19_7A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_7B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_7C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK19_7D   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR" ;
label define AK19_7DR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_1A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_1B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_1C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK20_1CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK20_2A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_2B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_2C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK20_2CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK20_4A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_4B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_4C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK20_4CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK20_5A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_5B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_5C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK20_5CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK20_6A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_6B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_6C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK20_6CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK20_7A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_7B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_7C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK20_7CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK20_8A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_8B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK20_8C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK20_8CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK21_1A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK21_1B3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_1C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK21_1CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_2A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK212B3   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_2C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK21_2CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_4A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK21_4B3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_4C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK21_4CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_5A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK21_5B3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_5C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK21_5CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_6A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK21_6B3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_6C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK21_6CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_7A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK21_7B3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_7C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK21_7CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_8A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK21_8B3  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK21_8C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK21_8CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK22      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_1A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_1B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_1C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK22_1CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK22_2A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_2B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_2C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK22_2CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK22_4A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_4B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_4C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK22_4CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK22_5A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_5B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_5C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK22_5CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK22_6A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_6B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_6C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK22_6CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK22_7A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_7B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_7C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK22_7CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK22_8A   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_8B   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AK22_8C   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "WITHIN PAST 12 MOS"
                       3 "MORE THAN 1 YR AGO" ;
label define AK22_8CR  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AK23_A    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AK23_B    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AK23_C    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AK23_D    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AK23_E    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AK23_F    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AK23_G    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AL1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AL2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AL2A      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 999 "999 OR MORE" ;
label define AL3_1_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define AL3_1_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MILD" 2 "MODERATE"
                       3 "EXTREME" ;
label define AL3_2_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define AL3_2_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MILD" 2 "MODERATE"
                       3 "EXTREME" ;
label define AL3_3_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define AL3_3_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MILD" 2 "MODERATE"
                       3 "EXTREME" ;
label define AL3_4_1   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define AL3_4_2   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MILD" 2 "MODERATE"
                       3 "EXTREME" ;
label define AL4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AL4A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CIRCLED" ;
label define AL4A2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 2 "CIRCLED" ;
label define AL4A3     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 3 "CIRCLED" ;
label define AL4A4     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 4 "CIRCLED" ;
label define AL4A5     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 5 "CIRCLED" ;
label define AL4A6     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 6 "CIRCLED" ;
label define AL5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "EAGER" 2 "RECEPTIVE"
                       3 "NO REACTION" 4 "RELUCTANT" 5 "REFUSED"
                       6 "NOT DISCUSSED" ;
label define AL6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AL6A1     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AL6A2     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define AM1       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define AM2       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM3       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM4       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM5       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM6       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM7       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM8       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM9       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM10A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM10B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM11A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM11B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM11C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM12A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define AM12B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define AM12C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define AM12D     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define AM12E     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT" 5 "ERROR"
                       7 "SAYS CANT DO" ;
label define AM13      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO ERROR" 1 "1 ERROR"
                       2 "2 ERRORS" 3 "3 ERRORS" 4 "4 ERRORS" 5 "5 ERRORS" ;
label define AM14A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM14B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM14C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" ;
label define AM15A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define AM15B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define AM16      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define AM17      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP"
                       7 "CANT READ ENGLISH" ;
label define AM18A     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define AM18B     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define AM18C     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO/REFUSE" 6 "HANDICAP" ;
label define AM19      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO" 6 "HANDICAP"
                       7 "CANT WRITE (ENGLISH)" ;
label define AM20      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "CORRECT"
                       5 "ERROR/CANT DO" 6 "HANDICAP" ;
label define AM21      -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "YES" 2 "NO" ;
label define SEX       1 "MALE" 2 "FEMALE" ;
label define AGE       -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;
label define AGEGRP    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "UNDER 18" 2 "18-20"
                       3 "21-25" 4 "26-30" 5 "31-35" 6 "36-44" 7 "OVER 44"
                       55 "55 OR OLDER" 94 "1 OR DK, BUT < 15"
                       95 "DK, BUT 15 OR OLDER" ;
label define RACE      1 "CAUCASIAN/WHITE" 2 "AFRO-AMERICAN/BLACK"
                       3 "HISPANIC" 4 "OTHER" ;
label define RACESEX   1 "CAUCASIAN/WHITE MALE" 2 "AFRO-AMERICAN/BLACK MALE"
                       3 "HISPANIC MALE" 4 "OTHER MALE"
                       5 "CAUCASIAN/WHITE FEMALE"
                       6 "AFRO-AMERICAN/BLACK FEMALE" 7 "HISPANIC FEMALE"
                       8 "OTHER FEMALE" ;
label define MSTAT     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 1 "MARRIED" 2 "SEPARATED"
                       3 "DIVORCED" 4 "WIDOWED" 5 "LIVING AS MARRIED"
                       6 "NEVER MARRIED" ;
label define FTWORK    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "1-13 WKS"
                       2 "14-39 WKS" 3 "40-52 WKS" ;
label define EDLEV     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE"
                       1 "GRADE SCHOOL OR LESS" 2 "HIGH SCHOOL"
                       3 "HIGH SCHOOL DEGREE" 4 "SOME COLLEGE"
                       5 "JR COLLEGE/ASSOCIATE DEGREE" 6 "COLLEGE DEGREE"
                       7 "ADVANCED DEGREE" ;
label define HLTHINS   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NONE" 1 "PRIV/OTHER"
                       2 "PUB" ;
label define MAJSRC    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO INCOME" 1 "LEGAL WORK"
                       2 "PUB ASSISTANCE" 3 "SOCIAL SECURITY"
                       4 "FAMILY, FRIENDS" 5 "ILLEGAL SOURCES"
                       6 "OTHER SOURCES" ;
label define REFER     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "SELF-REFERRAL"
                       1 "MEDICAL SERVICE" 10 "COMMUNITY AGENCY"
                       20 "LEGAL SYSTEM (NOT PROBAT/PAROLE)"
                       30 "PROBATION/PAROLE" 40 "PRISON SYSTEM"
                       50 "FAMILY OR FRIENDS" 60 "SCHOOL" 70 "EMPLOYER"
                       80 "VETERAN" 90 "OTHER" ;
label define CJ_STAT   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO LEGAL STATUS"
                       1 "IN JAIL/DETENTION" 2 "PROBATION" 3 "PAROLE"
                       4 "CASE PENDING" ;
label define RESTRICT  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO WKS RESTRICTED"
                       1 "1-4 WKS RESTRICTED" 2 "5-13 WKS RESTRICTED"
                       3 "14-26 WKS RESTRICTED" 4 "27-39 WKS RESTRICTED"
                       5 "40-50 WKS RESTRICTED" 6 "51-52 WKS RESTRICTED" ;
label define PDRUG     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO FAVORITE DRUG"
                       10 "ALCOHOL" 20 "MARIJUANA" 30 "HALLUCINOGEN"
                       40 "COCAINE/CRACK" 50 "HEROIN"
                       60 "NARCOTICS/OTHER OPIATES" 70 "SEDATIVES"
                       80 "AMPHETAMINES" 90 "OTHER" 91 "INHALANTS" ;
label define PDRUGFRQ  -9 "NO PRIMARY DRUG DENOTED" 0 "NO USE"
                       1 "LESS THAN ONCE/WEEK" 2 "1-3 TIMES/MONTH"
                       3 "1-2 TIMES/WEEK" 4 "3-4 TIMES/WEEK"
                       5 "5-6 TIMES/WEEK" 6 "DAILY OR ALMOST EVERY DAY"
                       7 "2-3 TIMES/DAY" 8 "4+ TIMES/DAY" ;
label define FAVDRUG   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NO FAVORITE DRUG"
                       10 "ALCOHOL" 20 "MARIJUANA" 30 "HALLUCINOGEN"
                       40 "COCAINE/CRACK" 50 "HEROIN"
                       60 "NARCOTICS/OTHER OPIATES" 70 "SEDATIVES"
                       80 "AMPHETAMINES" 90 "OTHER" 91 "INHALANTS" ;
label define HVY_ALC   -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NOT A HEAVY USER"
                       1 "HEAVY ALCOHOL USER" ;
label define DRUGPAT   1 "HEROIN/NARCOTIC/NO COKE"
                       2 "COKE W/HEROIN OR NARCOTICS" 3 "COKE ONLY"
                       4 "COKE AND ALCOHOL" 5 "COKE PLUS OTHER DRUGS"
                       6 "MARIJUANA AND/OR ALCOHOL" 7 "RESIDUAL" ;
label define TOPS_PAT  1 "HEROIN" 2 "HEROIN AND OPIOIDS" 3 "OTHER OPIOIDS"
                       4 "MULTIPLE NON-OPIOIDS" 5 "SINGLE NON-OPIOIDS"
                       6 "MARIJUANA AND/OR ALCOHOL" 7 "RESIDUAL/MINIMAL USE" ;
label define ALCWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define MRJWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define COCWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define CRKWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define HERWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define NARWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define SEDWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define AMPWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define HALWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define INHWK     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "LESS THAN WEEKLY USE"
                       1 "WEEKLY OR MORE USE" ;
label define HERHX     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER USED"
                       1 "USED 1-5 TIMES ONLY"
                       2 "USED SPORADICALLY OR MONTHLY"
                       3 "USED MORE THAN 4 WKS ON WEEKLY BASIS"
                       4 "USED MORE THAN 4 WKS ON DAILY BASIS" ;
label define COCHX     -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 0 "NEVER USED"
                       1 "1-5 TIMES ONLY" 2 "SPORADICALLY/MONTHLY"
                       3 ">4 WKS ON WEEKLY BASIS" 4 ">4 WKS ON DAILY BASIS" ;
label define DRUGTX    -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" ;
label define DRGTXAGE  -9 "LEGITIMATE SKIP" -8 "BLANK" -7 "REFUSAL"
                       -6 "MULTIPLE RESPONSE" -5 "BAD DATA" -4 "DON'T KNOW"
                       -3 "NOT APPLICABLE" -2 "ILLEGIBLE"
                       -1 "VARIABLE NOT ON FORM" 55 "55 OR OLDER"
                       94 "1 OR DK, BUT < 15" 95 "DK, BUT 15 OR OLDER" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace ADC1 = . if (ADC1 <= -1 )
replace ADC3 = . if (ADC3 <= -1 )
replace ATLI = . if (ATLI <= -1 )
replace AA3 = . if (AA3 <= -1 )
replace AA3A = . if (AA3A <= -1 )
replace AA4 = . if (AA4 <= -1 )
replace AA4A = . if (AA4A <= -1 )
replace AA4B = . if (AA4B <= -1 )
replace AA8 = . if (AA8 <= -1 )
replace AA9 = . if (AA9 <= -1 )
replace AA9A = . if (AA9A <= -1 )
replace AA9B = . if (AA9B <= -1 )
replace AA10 = . if (AA10 <= -1 )
replace AA10B = . if (AA10B <= -1 )
replace AA11_3 = . if (AA11_3 <= -1 )
replace AA12 = . if (AA12 <= -1 )
replace AA13 = . if (AA13 <= -1 )
replace AA14_1 = . if (AA14_1 <= -1 )
replace AA14_2 = . if (AA14_2 <= -1 )
replace AA14_3 = . if (AA14_3 <= -1 )
replace AA14_4 = . if (AA14_4 <= -1 )
replace AA14_5 = . if (AA14_5 <= -1 )
replace AA14_6 = . if (AA14_6 <= -1 )
replace AA15 = . if (AA15 <= -1 )
replace AA15B = . if (AA15B <= -1 )
replace AA16 = . if (AA16 <= -1 )
replace AA17_3 = . if (AA17_3 <= -1 )
replace AB1 = . if (AB1 <= -1 )
replace AB1A = . if (AB1A <= -1 )
replace AB1B = . if (AB1B <= -1 )
replace AB1C = . if (AB1C <= -1 )
replace AB2 = . if (AB2 <= -1 )
replace AB2A = . if (AB2A <= -1 )
replace AB3_1 = . if (AB3_1 <= -1 )
replace AB3_2 = . if (AB3_2 <= -1 )
replace AB3_3 = . if (AB3_3 <= -1 )
replace AB3_4 = . if (AB3_4 <= -1 )
replace AB3_5 = . if (AB3_5 <= -1 )
replace AB3_6 = . if (AB3_6 <= -1 )
replace AB3_7 = . if (AB3_7 <= -1 )
replace AB4 = . if (AB4 <= -1 )
replace AB4A = . if (AB4A <= -1 )
replace AB4B = . if (AB4B <= -1 )
replace AB5 = . if (AB5 <= -1 )
replace AB5A = . if (AB5A <= -1 )
replace AB6 = . if (AB6 <= -1 )
replace AB6A = . if (AB6A <= -1 )
replace AB7 = . if (AB7 <= -1 )
replace AB7A = . if (AB7A <= -1 )
replace AB7B = . if (AB7B <= -1 )
replace AB7C = . if (AB7C <= -1 )
replace AB7C_M = . if (AB7C_M <= -1 )
replace AB7D = . if (AB7D <= -1 )
replace AB7E = . if (AB7E <= -1 )
replace AB7E_M = . if (AB7E_M <= -1 )
replace AB8 = . if (AB8 <= -1 )
replace AB8A = . if (AB8A <= -1 )
replace AB8B = . if (AB8B <= -1 )
replace AB8C = . if (AB8C <= -1 )
replace AB9 = . if (AB9 <= -1 )
replace AB10 = . if (AB10 <= -1 )
replace AB10A = . if (AB10A <= -1 )
replace AB10B = . if (AB10B <= -1 )
replace AB11 = . if (AB11 <= -1 )
replace AC1 = . if (AC1 <= -1 )
replace AC1A1 = . if (AC1A1 <= -1 )
replace AC1A3 = . if (AC1A3 <= -1 )
replace AC1B1 = . if (AC1B1 <= -1 )
replace AC1B3 = . if (AC1B3 <= -1 )
replace AC2_1 = . if (AC2_1 <= -1 )
replace AC2A1 = . if (AC2A1 <= -1 )
replace AC2A2 = . if (AC2A2 <= -1 )
replace AC2A3 = . if (AC2A3 <= -1 )
replace AC3 = . if (AC3 <= -1 )
replace AC3A = . if (AC3A <= -1 )
replace AC4 = . if (AC4 <= -1 )
replace AC4A1 = . if (AC4A1 <= -1 )
replace AC4A2 = . if (AC4A2 <= -1 )
replace AC5 = . if (AC5 <= -1 )
replace AC6 = . if (AC6 <= -1 )
replace AC6A = . if (AC6A <= -1 )
replace AC7 = . if (AC7 <= -1 )
replace AC7A_1 = . if (AC7A_1 <= -1 )
replace AC7A_2 = . if (AC7A_2 <= -1 )
replace AC7A_3 = . if (AC7A_3 <= -1 )
replace AC7A_4 = . if (AC7A_4 <= -1 )
replace AC7A_5 = . if (AC7A_5 <= -1 )
replace AC7A_6 = . if (AC7A_6 <= -1 )
replace AC7A_7 = . if (AC7A_7 <= -1 )
replace AC7B = . if (AC7B <= -1 )
replace AC7C = . if (AC7C <= -1 )
replace AC7D = . if (AC7D <= -1 )
replace AC7E = . if (AC7E <= -1 )
replace AC8_0 = . if (AC8_0 <= -1 )
replace AC8_1 = . if (AC8_1 <= -1 )
replace AC8_2 = . if (AC8_2 <= -1 )
replace AC8_3 = . if (AC8_3 <= -1 )
replace AC8_4 = . if (AC8_4 <= -1 )
replace AC8_5 = . if (AC8_5 <= -1 )
replace AC8_6 = . if (AC8_6 <= -1 )
replace AC8_7 = . if (AC8_7 <= -1 )
replace AC8_8 = . if (AC8_8 <= -1 )
replace AC8_9 = . if (AC8_9 <= -1 )
replace AC9 = . if (AC9 <= -1 )
replace AC9A = . if (AC9A <= -1 )
replace AC9B = . if (AC9B <= -1 )
replace AC9C = . if (AC9C <= -1 )
replace AC9D = . if (AC9D <= -1 )
replace AC9E = . if (AC9E <= -1 )
replace AC10 = . if (AC10 <= -1 )
replace AC11 = . if (AC11 <= -1 )
replace AD1 = . if (AD1 <= -1 )
replace AD1A = . if (AD1A <= -1 )
replace AD2 = . if (AD2 <= -1 )
replace AD2A = . if (AD2A <= -1 )
replace AD2B = . if (AD2B <= -1 )
replace AD2B_M = . if (AD2B_M <= -1 )
replace AD3 = . if (AD3 <= -1 )
replace AD3A = . if (AD3A <= -1 )
replace AD3B = . if (AD3B <= -1 )
replace AD3B_M = . if (AD3B_M <= -1 )
replace AD4 = . if (AD4 <= -1 )
replace AD4A = . if (AD4A <= -1 )
replace AD4B = . if (AD4B <= -1 )
replace AD4B_M = . if (AD4B_M <= -1 )
replace AD5 = . if (AD5 <= -1 )
replace AD5A = . if (AD5A <= -1 )
replace AD6 = . if (AD6 <= -1 )
replace AD7 = . if (AD7 <= -1 )
replace AD8 = . if (AD8 <= -1 )
replace AD8A = . if (AD8A <= -1 )
replace AD9 = . if (AD9 <= -1 )
replace AD9_M = . if (AD9_M <= -1 )
replace AD9A = . if (AD9A <= -1 )
replace AD9B = . if (AD9B <= -1 )
replace AD9C = . if (AD9C <= -1 )
replace AD9D = . if (AD9D <= -1 )
replace AD9E = . if (AD9E <= -1 )
replace AD9F = . if (AD9F <= -1 )
replace AD10 = . if (AD10 <= -1 )
replace AD10A = . if (AD10A <= -1 )
replace AD10B = . if (AD10B <= -1 )
replace AD10C = . if (AD10C <= -1 )
replace AD10D = . if (AD10D <= -1 )
replace AD10D_M = . if (AD10D_M <= -1 )
replace AD11 = . if (AD11 <= -1 )
replace AD12 = . if (AD12 <= -1 )
replace AD13 = . if (AD13 <= -1 )
replace AD13A = . if (AD13A <= -1 )
replace AD14A = . if (AD14A <= -1 )
replace AD14B = . if (AD14B <= -1 )
replace AD14C = . if (AD14C <= -1 )
replace AD14D = . if (AD14D <= -1 )
replace AD14E = . if (AD14E <= -1 )
replace AD15 = . if (AD15 <= -1 )
replace AD15A = . if (AD15A <= -1 )
replace AD16 = . if (AD16 <= -1 )
replace AD16_M = . if (AD16_M <= -1 )
replace AD16A = . if (AD16A <= -1 )
replace AD17 = . if (AD17 <= -1 )
replace AD17A = . if (AD17A <= -1 )
replace AD17A_M = . if (AD17A_M <= -1 )
replace AD17B3 = . if (AD17B3 <= -1 )
replace AD18 = . if (AD18 <= -1 )
replace AD18A = . if (AD18A <= -1 )
replace AD18A_M = . if (AD18A_M <= -1 )
replace AD19 = . if (AD19 <= -1 )
replace AD19A = . if (AD19A <= -1 )
replace AD20_0 = . if (AD20_0 <= -1 )
replace AD20_1 = . if (AD20_1 <= -1 )
replace AD20_2 = . if (AD20_2 <= -1 )
replace AD20_3 = . if (AD20_3 <= -1 )
replace AE1 = . if (AE1 <= -1 )
replace AE1A = . if (AE1A <= -1 )
replace AE1B = . if (AE1B <= -1 )
replace AE1C = . if (AE1C <= -1 )
replace AE1D = . if (AE1D <= -1 )
replace AE1E = . if (AE1E <= -1 )
replace AE1E_M = . if (AE1E_M <= -1 )
replace AE1F = . if (AE1F <= -1 )
replace AE1F_M = . if (AE1F_M <= -1 )
replace AE1G = . if (AE1G <= -1 )
replace AE2 = . if (AE2 <= -1 )
replace AE2A = . if (AE2A <= -1 )
replace AE2B = . if (AE2B <= -1 )
replace AE2C = . if (AE2C <= -1 )
replace AE2D = . if (AE2D <= -1 )
replace AE2E = . if (AE2E <= -1 )
replace AE2F3 = . if (AE2F3 <= -1 )
replace AE2G = . if (AE2G <= -1 )
replace AE2H = . if (AE2H <= -1 )
replace AE2I = . if (AE2I <= -1 )
replace AE2J3 = . if (AE2J3 <= -1 )
replace AE2K = . if (AE2K <= -1 )
replace AE2L = . if (AE2L <= -1 )
replace AE2M = . if (AE2M <= -1 )
replace AE2M_M = . if (AE2M_M <= -1 )
replace AE2N = . if (AE2N <= -1 )
replace AE2N_M = . if (AE2N_M <= -1 )
replace AE2O = . if (AE2O <= -1 )
replace AE2P = . if (AE2P <= -1 )
replace AE2Q = . if (AE2Q <= -1 )
replace AE2R = . if (AE2R <= -1 )
replace AE2R_M = . if (AE2R_M <= -1 )
replace AE2S = . if (AE2S <= -1 )
replace AE3 = . if (AE3 <= -1 )
replace AE3A = . if (AE3A <= -1 )
replace AE3B = . if (AE3B <= -1 )
replace AE3C = . if (AE3C <= -1 )
replace AE3D = . if (AE3D <= -1 )
replace AE3E = . if (AE3E <= -1 )
replace AE3F3 = . if (AE3F3 <= -1 )
replace AE3G = . if (AE3G <= -1 )
replace AE3H = . if (AE3H <= -1 )
replace AE3I = . if (AE3I <= -1 )
replace AE3J3 = . if (AE3J3 <= -1 )
replace AE3K = . if (AE3K <= -1 )
replace AE3L = . if (AE3L <= -1 )
replace AE3M = . if (AE3M <= -1 )
replace AE3M_M = . if (AE3M_M <= -1 )
replace AE3N = . if (AE3N <= -1 )
replace AE3N_M = . if (AE3N_M <= -1 )
replace AE3O = . if (AE3O <= -1 )
replace AE3P = . if (AE3P <= -1 )
replace AE3Q = . if (AE3Q <= -1 )
replace AE3R = . if (AE3R <= -1 )
replace AE3R_M = . if (AE3R_M <= -1 )
replace AE3S = . if (AE3S <= -1 )
replace AE3T = . if (AE3T <= -1 )
replace AE4 = . if (AE4 <= -1 )
replace AE4A1 = . if (AE4A1 <= -1 )
replace AE4A2 = . if (AE4A2 <= -1 )
replace AE4A3 = . if (AE4A3 <= -1 )
replace AE4B = . if (AE4B <= -1 )
replace AE5 = . if (AE5 <= -1 )
replace AE5A = . if (AE5A <= -1 )
replace AE5B = . if (AE5B <= -1 )
replace AE5C = . if (AE5C <= -1 )
replace AE5D = . if (AE5D <= -1 )
replace AE5E = . if (AE5E <= -1 )
replace AE5F3 = . if (AE5F3 <= -1 )
replace AE5G = . if (AE5G <= -1 )
replace AE5H3 = . if (AE5H3 <= -1 )
replace AE5I = . if (AE5I <= -1 )
replace AE5J = . if (AE5J <= -1 )
replace AE5K = . if (AE5K <= -1 )
replace AE5K_M = . if (AE5K_M <= -1 )
replace AE5L = . if (AE5L <= -1 )
replace AE5L_M = . if (AE5L_M <= -1 )
replace AE5M = . if (AE5M <= -1 )
replace AE5N = . if (AE5N <= -1 )
replace AE5O = . if (AE5O <= 0 )
replace AE5P = . if (AE5P <= -1 )
replace AE5P_M = . if (AE5P_M <= -1 )
replace AE5Q = . if (AE5Q <= -1 )
replace AE6 = . if (AE6 <= -1 )
replace AE6A = . if (AE6A <= -1 )
replace AE6BS1 = . if (AE6BS1 <= -1 )
replace AE6BS2 = . if (AE6BS2 <= -1 )
replace AE6BS3 = . if (AE6BS3 <= -1 )
replace AE6BT1 = . if (AE6BT1 <= -1 )
replace AE6BT2 = . if (AE6BT2 <= -1 )
replace AE6BT3 = . if (AE6BT3 <= -1 )
replace AE6C = . if (AE6C <= -1 )
replace AE7 = . if (AE7 <= -1 )
replace AE7A = . if (AE7A <= -1 )
replace AE7B = . if (AE7B <= -1 )
replace AE7C = . if (AE7C <= -1 )
replace AE7D = . if (AE7D <= -1 )
replace AE7E = . if (AE7E <= -1 )
replace AE7F3 = . if (AE7F3 <= -1 )
replace AE7G = . if (AE7G <= -1 )
replace AE7H3 = . if (AE7H3 <= -1 )
replace AE7I = . if (AE7I <= -1 )
replace AE7J = . if (AE7J <= -1 )
replace AE7K = . if (AE7K <= -1 )
replace AE7K_M = . if (AE7K_M <= -1 )
replace AE7L = . if (AE7L <= -1 )
replace AE7L_M = . if (AE7L_M <= -1 )
replace AE7M = . if (AE7M <= -1 )
replace AE7N = . if (AE7N <= -1 )
replace AE7O71 = . if (AE7O71 <= -1 )
replace AE7O72 = . if (AE7O72 <= -1 )
replace AE7O73 = . if (AE7O73 <= -1 )
replace AE7O74 = . if (AE7O74 <= -1 )
replace AE7P = . if (AE7P <= -1 )
replace AE8 = . if (AE8 <= -1 )
replace AE8A = . if (AE8A <= -1 )
replace AE8B1 = . if (AE8B1 <= -1 )
replace AE8B2 = . if (AE8B2 <= -1 )
replace AE8B3 = . if (AE8B3 <= -1 )
replace AE8C = . if (AE8C <= -1 )
replace AE9 = . if (AE9 <= -1 )
replace AE9A = . if (AE9A <= -1 )
replace AE9B = . if (AE9B <= -1 )
replace AE9C = . if (AE9C <= -1 )
replace AE9D = . if (AE9D <= -1 )
replace AE9E = . if (AE9E <= -1 )
replace AE9F3 = . if (AE9F3 <= -1 )
replace AE9G = . if (AE9G <= -1 )
replace AE9H3 = . if (AE9H3 <= -1 )
replace AE9I = . if (AE9I <= -1 )
replace AE9J = . if (AE9J <= -1 )
replace AE9K = . if (AE9K <= -1 )
replace AE9K_M = . if (AE9K_M <= -1 )
replace AE9L = . if (AE9L <= -1 )
replace AE9L_M = . if (AE9L_M <= -1 )
replace AE9M = . if (AE9M <= -1 )
replace AE9N = . if (AE9N <= -1 )
replace AE9O = . if (AE9O <= -1 )
replace AE9P = . if (AE9P <= -1 )
replace AE9P_M = . if (AE9P_M <= -1 )
replace AE9Q = . if (AE9Q <= -1 )
replace AE9R = . if (AE9R <= -1 )
replace AE10 = . if (AE10 <= -1 )
replace AE10A = . if (AE10A <= -1 )
replace AE11 = . if (AE11 <= -1 )
replace AE11A = . if (AE11A <= -1 )
replace AE11B = . if (AE11B <= -1 )
replace AE11C = . if (AE11C <= -1 )
replace AE11D = . if (AE11D <= -1 )
replace AE11E = . if (AE11E <= -1 )
replace AE11F3 = . if (AE11F3 <= -1 )
replace AE11G = . if (AE11G <= -1 )
replace AE11H = . if (AE11H <= -1 )
replace AE11H_M = . if (AE11H_M <= -1 )
replace AE11I = . if (AE11I <= -1 )
replace AE11I_M = . if (AE11I_M <= -1 )
replace AE11J = . if (AE11J <= -1 )
replace AE11K = . if (AE11K <= -1 )
replace AE11L = . if (AE11L <= 0 )
replace AE11M = . if (AE11M <= -1 )
replace AE11M_M = . if (AE11M_M <= -1 )
replace AE11N = . if (AE11N <= -1 )
replace AE11O = . if (AE11O <= -1 )
replace AE12 = . if (AE12 <= -1 )
replace AE12A = . if (AE12A <= -1 )
replace AE12B = . if (AE12B <= -1 )
replace AE12C = . if (AE12C <= -1 )
replace AE12D = . if (AE12D <= -1 )
replace AE12E = . if (AE12E <= -1 )
replace AE12E_M = . if (AE12E_M <= -1 )
replace AE12F = . if (AE12F <= -1 )
replace AE12F_M = . if (AE12F_M <= -1 )
replace AE12G = . if (AE12G <= -1 )
replace AE13 = . if (AE13 <= -1 )
replace AE14 = . if (AE14 <= -1 )
replace AE14A = . if (AE14A <= -1 )
replace AE14B = . if (AE14B <= -1 )
replace AE14C = . if (AE14C <= 0 )
replace AE14D = . if (AE14D <= -1 )
replace AE14E = . if (AE14E <= -1 )
replace AE14E_M = . if (AE14E_M <= -1 )
replace AE14F = . if (AE14F <= -1 )
replace AE14G = . if (AE14G <= -1 )
replace AE14H = . if (AE14H <= -1 )
replace AE15 = . if (AE15 <= -1 )
replace AE15A = . if (AE15A <= -1 )
replace AE15B = . if (AE15B <= -1 )
replace AE15C = . if (AE15C <= -1 )
replace AE15D = . if (AE15D <= -1 )
replace AE15E = . if (AE15E <= -1 )
replace AE15E_M = . if (AE15E_M <= -1 )
replace AE15F = . if (AE15F <= -1 )
replace AE15G = . if (AE15G <= -1 )
replace AE15H = . if (AE15H <= -1 )
replace AE16 = . if (AE16 <= -1 )
replace AE16A = . if (AE16A <= -1 )
replace AE16B = . if (AE16B <= -1 )
replace AE16C = . if (AE16C <= -1 )
replace AE16D = . if (AE16D <= -1 )
replace AE16E = . if (AE16E <= -1 )
replace AE16E_M = . if (AE16E_M <= -1 )
replace AE16F = . if (AE16F <= -1 )
replace AE16G = . if (AE16G <= -1 )
replace AE16H = . if (AE16H <= -1 )
replace AE17 = . if (AE17 <= -1 )
replace AE18 = . if (AE18 <= -1 )
replace AE19 = . if (AE19 <= -1 )
replace AE19A = . if (AE19A <= -1 )
replace AE19B = . if (AE19B <= -1 )
replace AE19C1 = . if (AE19C1 <= -1 )
replace AE19C2 = . if (AE19C2 <= -1 )
replace AE19C3 = . if (AE19C3 <= -1 )
replace AE20 = . if (AE20 <= -1 )
replace AE21 = . if (AE21 <= -1 )
replace AE21A = . if (AE21A <= -1 )
replace AE22 = . if (AE22 <= -1 )
replace AE22A = . if (AE22A <= -1 )
replace AE22B1 = . if (AE22B1 <= -1 )
replace AE22B2 = . if (AE22B2 <= -1 )
replace AE22B3 = . if (AE22B3 <= -1 )
replace AE22B4 = . if (AE22B4 <= -1 )
replace AE22B5 = . if (AE22B5 <= -1 )
replace AE22B6 = . if (AE22B6 <= -1 )
replace AE23 = . if (AE23 <= -1 )
replace AE24A = . if (AE24A <= -1 )
replace AE24B = . if (AE24B <= -1 )
replace AE24C = . if (AE24C <= -1 )
replace AE24D = . if (AE24D <= -1 )
replace AE24E = . if (AE24E <= -1 )
replace AE24F = . if (AE24F <= -1 )
replace AE25 = . if (AE25 <= -1 )
replace AE25A = . if (AE25A <= -1 )
replace AE26A = . if (AE26A <= -1 )
replace AE26AA = . if (AE26AA <= -1 )
replace AE26AB = . if (AE26AB <= -1 )
replace AE26AC = . if (AE26AC <= -1 )
replace AE26AD1 = . if (AE26AD1 <= -1 )
replace AE26AD2 = . if (AE26AD2 <= -1 )
replace AE26AE = . if (AE26AE <= -1 )
replace AE26B = . if (AE26B <= -1 )
replace AE26BA = . if (AE26BA <= -1 )
replace AE26BB = . if (AE26BB <= -1 )
replace AE26BC = . if (AE26BC <= -1 )
replace AE26BD1 = . if (AE26BD1 <= -1 )
replace AE26BD2 = . if (AE26BD2 <= -1 )
replace AE26BE = . if (AE26BE <= -1 )
replace AE26C = . if (AE26C <= -1 )
replace AE26CA = . if (AE26CA <= -1 )
replace AE26CB = . if (AE26CB <= -1 )
replace AE26CC = . if (AE26CC <= -1 )
replace AE26CD1 = . if (AE26CD1 <= -1 )
replace AE26CD2 = . if (AE26CD2 <= -1 )
replace AE26CE = . if (AE26CE <= -1 )
replace AE26D = . if (AE26D <= -1 )
replace AE26DA = . if (AE26DA <= -1 )
replace AE26DB = . if (AE26DB <= -1 )
replace AE26DC = . if (AE26DC <= -1 )
replace AE26DD1 = . if (AE26DD1 <= -1 )
replace AE26DD2 = . if (AE26DD2 <= -1 )
replace AE26DE = . if (AE26DE <= -1 )
replace AE26E = . if (AE26E <= -1 )
replace AE26EA = . if (AE26EA <= -1 )
replace AE26EB = . if (AE26EB <= -1 )
replace AE26EC = . if (AE26EC <= -1 )
replace AE26ED1 = . if (AE26ED1 <= -1 )
replace AE26ED2 = . if (AE26ED2 <= -1 )
replace AE26EE = . if (AE26EE <= -1 )
replace AE26F = . if (AE26F <= -1 )
replace AE26FA = . if (AE26FA <= -1 )
replace AE26FB = . if (AE26FB <= -1 )
replace AE26FC = . if (AE26FC <= -1 )
replace AE26FD1 = . if (AE26FD1 <= -1 )
replace AE26FD2 = . if (AE26FD2 <= -1 )
replace AE26FE = . if (AE26FE <= -1 )
replace AE27_3 = . if (AE27_3 <= -1 )
replace AE28 = . if (AE28 <= -1 )
replace AE29 = . if (AE29 <= -1 )
replace AE30 = . if (AE30 <= -1 )
replace AE30_M = . if (AE30_M <= -1 )
replace AE31 = . if (AE31 <= -1 )
replace AE31A = . if (AE31A <= -1 )
replace AE31A_M = . if (AE31A_M <= -1 )
replace AE32 = . if (AE32 <= -1 )
replace AE32A3 = . if (AE32A3 <= -1 )
replace AE32B = . if (AE32B <= -1 )
replace AE32B_M = . if (AE32B_M <= -1 )
replace AE33 = . if (AE33 <= -1 )
replace AE33AA = . if (AE33AA <= -1 )
replace AE33BA = . if (AE33BA <= -1 )
replace AE33CA = . if (AE33CA <= -1 )
replace AE33AB = . if (AE33AB <= -1 )
replace AE33BB = . if (AE33BB <= -1 )
replace AE33CB = . if (AE33CB <= -1 )
replace AE33AC = . if (AE33AC <= -1 )
replace AE33BC = . if (AE33BC <= -1 )
replace AE33CC = . if (AE33CC <= -1 )
replace AE33AD = . if (AE33AD <= -1 )
replace AE33BD = . if (AE33BD <= -1 )
replace AE33CD = . if (AE33CD <= -1 )
replace AE33AE = . if (AE33AE <= -1 )
replace AE33BE = . if (AE33BE <= -1 )
replace AE33CE = . if (AE33CE <= -1 )
replace AF1 = . if (AF1 <= -1 )
replace AF1A = . if (AF1A <= -1 )
replace AF1B = . if (AF1B <= -1 )
replace AF1C = . if (AF1C <= -1 )
replace AF1D = . if (AF1D <= -1 )
replace AF1E = . if (AF1E <= -1 )
replace AF1E_M = . if (AF1E_M <= -1 )
replace AF2 = . if (AF2 <= -1 )
replace AF2A = . if (AF2A <= -1 )
replace AF2B = . if (AF2B <= -1 )
replace AF2C = . if (AF2C <= -1 )
replace AF2D = . if (AF2D <= -1 )
replace AF2E = . if (AF2E <= -1 )
replace AF2F = . if (AF2F <= -1 )
replace AF2G = . if (AF2G <= -1 )
replace AF2H = . if (AF2H <= -1 )
replace AF2H_M = . if (AF2H_M <= -1 )
replace AF3 = . if (AF3 <= -1 )
replace AF3A = . if (AF3A <= -1 )
replace AF3A_M = . if (AF3A_M <= -1 )
replace AF3B = . if (AF3B <= -1 )
replace AF4 = . if (AF4 <= -1 )
replace AF4A = . if (AF4A <= -1 )
replace AF4B = . if (AF4B <= -1 )
replace AF4B_M = . if (AF4B_M <= -1 )
replace AF4C = . if (AF4C <= -1 )
replace AF5 = . if (AF5 <= -1 )
replace AF5A = . if (AF5A <= -1 )
replace AF5B = . if (AF5B <= -1 )
replace AF5B_M = . if (AF5B_M <= -1 )
replace AF6 = . if (AF6 <= -1 )
replace AF6A = . if (AF6A <= -1 )
replace AF6B = . if (AF6B <= -1 )
replace AF6C = . if (AF6C <= -1 )
replace AF6C_M = . if (AF6C_M <= -1 )
replace AF7 = . if (AF7 <= -1 )
replace AF7A = . if (AF7A <= -1 )
replace AF7B = . if (AF7B <= -1 )
replace AF7B_M = . if (AF7B_M <= -1 )
replace AF8 = . if (AF8 <= -1 )
replace AF8A = . if (AF8A <= -1 )
replace AF9 = . if (AF9 <= -1 )
replace AF10 = . if (AF10 <= -1 )
replace AF11 = . if (AF11 <= -1 )
replace AF12 = . if (AF12 <= -1 )
replace AF12A = . if (AF12A <= -1 )
replace AF13A = . if (AF13A <= -1 )
replace AF13B = . if (AF13B <= -1 )
replace AF13C = . if (AF13C <= -1 )
replace AF13D = . if (AF13D <= -1 )
replace AF13E = . if (AF13E <= -1 )
replace AF13F = . if (AF13F <= -1 )
replace AF14 = . if (AF14 <= -1 )
replace AF14A = . if (AF14A <= -1 )
replace AF15 = . if (AF15 <= -1 )
replace AF15_M = . if (AF15_M <= -1 )
replace AF15A = . if (AF15A <= -1 )
replace AF16 = . if (AF16 <= -1 )
replace AF17A = . if (AF17A <= -1 )
replace AF17B = . if (AF17B <= -1 )
replace AF17C = . if (AF17C <= -1 )
replace AF17D = . if (AF17D <= -1 )
replace AF17E = . if (AF17E <= -1 )
replace AF17F = . if (AF17F <= -1 )
replace AF17G = . if (AF17G <= -1 )
replace AF18 = . if (AF18 <= -1 )
replace AF18A = . if (AF18A <= -1 )
replace AF19 = . if (AF19 <= -1 )
replace AF19_M = . if (AF19_M <= -1 )
replace AF20 = . if (AF20 <= -1 )
replace AF21 = . if (AF21 <= -1 )
replace AF22 = . if (AF22 <= -1 )
replace AF22A = . if (AF22A <= -1 )
replace AF23 = . if (AF23 <= -1 )
replace AF24 = . if (AF24 <= -1 )
replace AF24AA = . if (AF24AA <= -1 )
replace AF24BA = . if (AF24BA <= -1 )
replace AF24AB = . if (AF24AB <= -1 )
replace AF24BB = . if (AF24BB <= -1 )
replace AF24AC = . if (AF24AC <= -1 )
replace AF24BC = . if (AF24BC <= -1 )
replace AF24AD = . if (AF24AD <= -1 )
replace AF24BD = . if (AF24BD <= -1 )
replace AF24AE = . if (AF24AE <= -1 )
replace AF24BE = . if (AF24BE <= -1 )
replace AG1 = . if (AG1 <= -1 )
replace AG1A = . if (AG1A <= -1 )
replace AG1B = . if (AG1B <= -1 )
replace AG1B_M = . if (AG1B_M <= -1 )
replace AG1C = . if (AG1C <= -1 )
replace AG1D = . if (AG1D <= -1 )
replace AG2 = . if (AG2 <= -1 )
replace AG3 = . if (AG3 <= -1 )
replace AG4 = . if (AG4 <= -1 )
replace AG4A = . if (AG4A <= -1 )
replace AG5 = . if (AG5 <= -1 )
replace AG6 = . if (AG6 <= -1 )
replace AG6A = . if (AG6A <= -1 )
replace AG6B = . if (AG6B <= -1 )
replace AG6B_M = . if (AG6B_M <= -1 )
replace AG7_1 = . if (AG7_1 <= -1 )
replace AG8_1 = . if (AG8_1 <= -1 )
replace AG9_1 = . if (AG9_1 <= -1 )
replace AG7_2 = . if (AG7_2 <= -1 )
replace AG8_2 = . if (AG8_2 <= -1 )
replace AG9_2 = . if (AG9_2 <= -1 )
replace AG7_3 = . if (AG7_3 <= -1 )
replace AG8_3 = . if (AG8_3 <= -1 )
replace AG9_3 = . if (AG9_3 <= -1 )
replace AG7_4 = . if (AG7_4 <= -1 )
replace AG8_4 = . if (AG8_4 <= -1 )
replace AG9_4 = . if (AG9_4 <= -1 )
replace AG7_5 = . if (AG7_5 <= -1 )
replace AG8_5 = . if (AG8_5 <= -1 )
replace AG9_5 = . if (AG9_5 <= -1 )
replace AG7_6 = . if (AG7_6 <= -1 )
replace AG8_6 = . if (AG8_6 <= -1 )
replace AG9_6 = . if (AG9_6 <= -1 )
replace AG7_7 = . if (AG7_7 <= -1 )
replace AG8_7 = . if (AG8_7 <= -1 )
replace AG9_7 = . if (AG9_7 <= -1 )
replace AG7_8 = . if (AG7_8 <= -1 )
replace AG8_8 = . if (AG8_8 <= -1 )
replace AG9_8 = . if (AG9_8 <= -1 )
replace AG7_9 = . if (AG7_9 <= -1 )
replace AG8_9 = . if (AG8_9 <= -1 )
replace AG9_9 = . if (AG9_9 <= -1 )
replace AG7_10 = . if (AG7_10 <= -1 )
replace AG8_10 = . if (AG8_10 <= -1 )
replace AG9_10 = . if (AG9_10 <= -1 )
replace AG7_11 = . if (AG7_11 <= -1 )
replace AG8_11 = . if (AG8_11 <= -1 )
replace AG9_11 = . if (AG9_11 <= -1 )
replace AG10 = . if (AG10 <= -1 )
replace AG11 = . if (AG11 <= -1 )
replace AG12 = . if (AG12 <= -1 )
replace AG13 = . if (AG13 <= -1 )
replace AG13A = . if (AG13A <= -1 )
replace AG13B = . if (AG13B <= -1 )
replace AG13B_M = . if (AG13B_M <= -1 )
replace AG14 = . if (AG14 <= -1 )
replace AG14A3 = . if (AG14A3 <= -1 )
replace AG14B3 = . if (AG14B3 <= -1 )
replace AG14C3 = . if (AG14C3 <= -1 )
replace AG15 = . if (AG15 <= -1 )
replace AG15A3 = . if (AG15A3 <= -1 )
replace AG15B = . if (AG15B <= -1 )
replace AG15B_M = . if (AG15B_M <= -1 )
replace AG15C = . if (AG15C <= -1 )
replace AG15D = . if (AG15D <= -1 )
replace AG16 = . if (AG16 <= -1 )
replace AG17 = . if (AG17 <= -1 )
replace AG18 = . if (AG18 <= -1 )
replace AG18A = . if (AG18A <= -1 )
replace AG19 = . if (AG19 <= -1 )
replace AG19A = . if (AG19A <= -1 )
replace AG20 = . if (AG20 <= -1 )
replace AG20A3 = . if (AG20A3 <= -1 )
replace AG20B1 = . if (AG20B1 <= -1 )
replace AG20B2 = . if (AG20B2 <= -1 )
replace AG20B3 = . if (AG20B3 <= -1 )
replace AG20B4 = . if (AG20B4 <= -1 )
replace AG20B5 = . if (AG20B5 <= -1 )
replace AG20B6 = . if (AG20B6 <= -1 )
replace AG20B7 = . if (AG20B7 <= -1 )
replace AG20C = . if (AG20C <= -1 )
replace AG20C_M = . if (AG20C_M <= -1 )
replace AG21 = . if (AG21 <= -1 )
replace AH1 = . if (AH1 <= -1 )
replace AH2 = . if (AH2 <= -1 )
replace AH2A = . if (AH2A <= -1 )
replace AH2B = . if (AH2B <= -1 )
replace AH2C = . if (AH2C <= -1 )
replace AH2D = . if (AH2D <= -1 )
replace AH2E = . if (AH2E <= -1 )
replace AH2F = . if (AH2F <= -1 )
replace AH2G = . if (AH2G <= -1 )
replace AH3 = . if (AH3 <= -1 )
replace AH3_01 = . if (AH3_01 <= -1 )
replace AH3_02 = . if (AH3_02 <= -1 )
replace AH3_03 = . if (AH3_03 <= -1 )
replace AH3_04 = . if (AH3_04 <= -1 )
replace AH3_05 = . if (AH3_05 <= -1 )
replace AH3_06 = . if (AH3_06 <= -1 )
replace AH3_07 = . if (AH3_07 <= -1 )
replace AH3B = . if (AH3B <= -1 )
replace AH3C1 = . if (AH3C1 <= -1 )
replace AH3C2 = . if (AH3C2 <= -1 )
replace AH3C4 = . if (AH3C4 <= -1 )
replace AH3C5 = . if (AH3C5 <= -1 )
replace AH3C6 = . if (AH3C6 <= -1 )
replace AH3C7 = . if (AH3C7 <= -1 )
replace AH3C8 = . if (AH3C8 <= -1 )
replace AH3C10 = . if (AH3C10 <= -1 )
replace AH3C11 = . if (AH3C11 <= -1 )
replace AH3D1 = . if (AH3D1 <= -1 )
replace AH3D2 = . if (AH3D2 <= -1 )
replace AH3D3 = . if (AH3D3 <= -1 )
replace AH3D4 = . if (AH3D4 <= -1 )
replace AH3D5 = . if (AH3D5 <= -1 )
replace AH3D6 = . if (AH3D6 <= -1 )
replace AH3D7 = . if (AH3D7 <= -1 )
replace AH3D8 = . if (AH3D8 <= -1 )
replace AH3D9 = . if (AH3D9 <= -1 )
replace AH3D10 = . if (AH3D10 <= -1 )
replace AH3D11 = . if (AH3D11 <= -1 )
replace AH3D12 = . if (AH3D12 <= -1 )
replace AH3D13 = . if (AH3D13 <= -1 )
replace AH3D14 = . if (AH3D14 <= -1 )
replace AH3D15 = . if (AH3D15 <= -1 )
replace AH3D16 = . if (AH3D16 <= -1 )
replace AH3D17 = . if (AH3D17 <= -1 )
replace AH4 = . if (AH4 <= -1 )
replace AH4A1 = . if (AH4A1 <= -1 )
replace AH4A2 = . if (AH4A2 <= -1 )
replace AH4A3 = . if (AH4A3 <= -1 )
replace AH4B = . if (AH4B <= -1 )
replace AH4C = . if (AH4C <= -1 )
replace AH4D = . if (AH4D <= -1 )
replace AH5 = . if (AH5 <= -1 )
replace AH6 = . if (AH6 <= -1 )
replace AH7 = . if (AH7 <= -1 )
replace AH8 = . if (AH8 <= -1 )
replace AH9 = . if (AH9 <= -1 )
replace AH9A = . if (AH9A <= -1 )
replace AH9B = . if (AH9B <= -1 )
replace AH9B1 = . if (AH9B1 <= -1 )
replace AH9C1 = . if (AH9C1 <= -1.00 )
replace AH9C2 = . if (AH9C2 <= -1 )
replace AH9D3 = . if (AH9D3 <= -1 )
replace AH9E = . if (AH9E <= -1 )
replace AH10 = . if (AH10 <= -1 )
replace AH10_M = . if (AH10_M <= -1 )
replace AH10A = . if (AH10A <= -1 )
replace AH10B = . if (AH10B <= -1 )
replace AH10C1 = . if (AH10C1 <= -1.00 )
replace AH10C2 = . if (AH10C2 <= -1 )
replace AH10D3 = . if (AH10D3 <= -1 )
replace AH10E = . if (AH10E <= -1 )
replace AH11_3 = . if (AH11_3 <= -1 )
replace AH11A = . if (AH11A <= -1 )
replace AH11A_M = . if (AH11A_M <= -1 )
replace AH11B = . if (AH11B <= -1 )
replace AH11C = . if (AH11C <= -1 )
replace AH11D1 = . if (AH11D1 <= -1.0000 )
replace AH11D2 = . if (AH11D2 <= -1 )
replace AH12 = . if (AH12 <= -1 )
replace AH13 = . if (AH13 <= -1 )
replace AH14 = . if (AH14 <= -1 )
replace AH14A = . if (AH14A <= -1 )
replace AH15 = . if (AH15 <= -1 )
replace AH15A = . if (AH15A <= -1 )
replace AH15B = . if (AH15B <= -1 )
replace AH15B_M = . if (AH15B_M <= -1 )
replace AH16 = . if (AH16 <= -1 )
replace AH16A = . if (AH16A <= -1 )
replace AH16B = . if (AH16B <= -1 )
replace AH16B_M = . if (AH16B_M <= -1 )
replace AH17 = . if (AH17 <= -1 )
replace AH17A = . if (AH17A <= -1 )
replace AH17B = . if (AH17B <= -1 )
replace AH17C = . if (AH17C <= -1 )
replace AH17D = . if (AH17D <= -1 )
replace AH17E = . if (AH17E <= -1 )
replace AH18 = . if (AH18 <= -1 )
replace AH18A = . if (AH18A <= -1 )
replace AH18B3 = . if (AH18B3 <= -1 )
replace AH19 = . if (AH19 <= -1 )
replace AH19A = . if (AH19A <= -1 )
replace AH19A_M = . if (AH19A_M <= -1 )
replace AH20 = . if (AH20 <= -1 )
replace AH21 = . if (AH21 <= -1 )
replace AH22 = . if (AH22 <= -1 )
replace AH22A = . if (AH22A <= -1 )
replace AJ1A = . if (AJ1A <= -1 )
replace AJ2A = . if (AJ2A <= -1 )
replace AJ1B = . if (AJ1B <= -1 )
replace AJ2B = . if (AJ2B <= -1 )
replace AJ1C = . if (AJ1C <= -1 )
replace AJ2C = . if (AJ2C <= -1 )
replace AJ1D = . if (AJ1D <= -1 )
replace AJ2D = . if (AJ2D <= -1 )
replace AJ1E = . if (AJ1E <= -1 )
replace AJ2E = . if (AJ2E <= -1 )
replace AJ1F = . if (AJ1F <= -1 )
replace AJ2F = . if (AJ2F <= -1 )
replace AJ2_TOT = . if (AJ2_TOT <= -1 )
replace AJ3 = . if (AJ3 <= -1 )
replace AJ4 = . if (AJ4 <= -1 )
replace AJ5 = . if (AJ5 <= -1 )
replace AJ5A = . if (AJ5A <= -1 )
replace AJ6 = . if (AJ6 <= -1 )
replace AJ7A1 = . if (AJ7A1 <= -1 )
replace AJ7A2 = . if (AJ7A2 <= -1 )
replace AJ7B1 = . if (AJ7B1 <= -1 )
replace AJ7B2 = . if (AJ7B2 <= -1 )
replace AJ7C1 = . if (AJ7C1 <= -1 )
replace AJ7C2 = . if (AJ7C2 <= -1 )
replace AJ7D1 = . if (AJ7D1 <= -1 )
replace AJ7D2 = . if (AJ7D2 <= -1 )
replace AJ8 = . if (AJ8 <= -1 )
replace AJ9 = . if (AJ9 <= -1 )
replace AJ10 = . if (AJ10 <= -1 )
replace AJ10A = . if (AJ10A <= -1 )
replace AJ11 = . if (AJ11 <= -1 )
replace AJ12 = . if (AJ12 <= -1 )
replace AJ12A = . if (AJ12A <= -1 )
replace AJ12A_M = . if (AJ12A_M <= -1 )
replace AJ12B = . if (AJ12B <= -1 )
replace AJ13 = . if (AJ13 <= -1 )
replace AJ14 = . if (AJ14 <= -1 )
replace AJ14A = . if (AJ14A <= -1 )
replace AJ14B = . if (AJ14B <= -1 )
replace AK1 = . if (AK1 <= -1 )
replace AK2 = . if (AK2 <= -1 )
replace AK12A1 = . if (AK12A1 <= -1 )
replace AK12B1 = . if (AK12B1 <= -1 )
replace AK12B1_M = . if (AK12B1_M <= -1 )
replace AK12A2 = . if (AK12A2 <= -1 )
replace AK12B2 = . if (AK12B2 <= -1 )
replace AK12B2_M = . if (AK12B2_M <= -1 )
replace AK12A4 = . if (AK12A4 <= -1 )
replace AK12B4 = . if (AK12B4 <= -1 )
replace AK12B4_M = . if (AK12B4_M <= -1 )
replace AK12A5 = . if (AK12A5 <= -1 )
replace AK12B5 = . if (AK12B5 <= -1 )
replace AK12B5_M = . if (AK12B5_M <= -1 )
replace AK12A6 = . if (AK12A6 <= -1 )
replace AK12B6 = . if (AK12B6 <= -1 )
replace AK12B6_M = . if (AK12B6_M <= -1 )
replace AK12A7 = . if (AK12A7 <= -1 )
replace AK12B7 = . if (AK12B7 <= -1 )
replace AK12B7_M = . if (AK12B7_M <= -1 )
replace AK12A8 = . if (AK12A8 <= -1 )
replace AK12B8 = . if (AK12B8 <= -1 )
replace AK12B8_M = . if (AK12B8_M <= -1 )
replace AK3 = . if (AK3 <= -1 )
replace AK3A1 = . if (AK3A1 <= -1 )
replace AK3B1 = . if (AK3B1 <= -1 )
replace AK3B1_M = . if (AK3B1_M <= -1 )
replace AK3A2 = . if (AK3A2 <= -1 )
replace AK3B2 = . if (AK3B2 <= -1 )
replace AK3B2_M = . if (AK3B2_M <= -1 )
replace AK3A4 = . if (AK3A4 <= -1 )
replace AK3B4 = . if (AK3B4 <= -1 )
replace AK3B4_M = . if (AK3B4_M <= -1 )
replace AK3A5 = . if (AK3A5 <= -1 )
replace AK3B5 = . if (AK3B5 <= -1 )
replace AK3B5_M = . if (AK3B5_M <= -1 )
replace AK3A6 = . if (AK3A6 <= -1 )
replace AK3B6 = . if (AK3B6 <= -1 )
replace AK3B6_M = . if (AK3B6_M <= -1 )
replace AK3A7 = . if (AK3A7 <= -1 )
replace AK3B7 = . if (AK3B7 <= -1 )
replace AK3B7_M = . if (AK3B7_M <= -1 )
replace AK3A8 = . if (AK3A8 <= -1 )
replace AK3B8 = . if (AK3B8 <= -1 )
replace AK3B8_M = . if (AK3B8_M <= -1 )
replace AK4 = . if (AK4 <= -1 )
replace AK4A1 = . if (AK4A1 <= -1 )
replace AK4B1 = . if (AK4B1 <= -1 )
replace AK4B1_M = . if (AK4B1_M <= -1 )
replace AK4A2 = . if (AK4A2 <= -1 )
replace AK4B2 = . if (AK4B2 <= -1 )
replace AK4B2_M = . if (AK4B2_M <= -1 )
replace AK4A4 = . if (AK4A4 <= -1 )
replace AK4B4 = . if (AK4B4 <= -1 )
replace AK4B4_M = . if (AK4B4_M <= -1 )
replace AK4A5 = . if (AK4A5 <= -1 )
replace AK4B5 = . if (AK4B5 <= -1 )
replace AK4B5_M = . if (AK4B5_M <= -1 )
replace AK4A6 = . if (AK4A6 <= -1 )
replace AK4B6 = . if (AK4B6 <= -1 )
replace AK4B6_M = . if (AK4B6_M <= -1 )
replace AK4A7 = . if (AK4A7 <= -1 )
replace AK4B7 = . if (AK4B7 <= -1 )
replace AK4B7_M = . if (AK4B7_M <= -1 )
replace AK4A8 = . if (AK4A8 <= -1 )
replace AK4B8 = . if (AK4B8 <= -1 )
replace AK4B8_M = . if (AK4B8_M <= -1 )
replace AK5 = . if (AK5 <= -1 )
replace AK6 = . if (AK6 <= -1 )
replace AK56A1 = . if (AK56A1 <= -1 )
replace AK56B1 = . if (AK56B1 <= -1 )
replace AK56B1_M = . if (AK56B1_M <= -1 )
replace AK56A2 = . if (AK56A2 <= -1 )
replace AK56B2 = . if (AK56B2 <= -1 )
replace AK56B2_M = . if (AK56B2_M <= -1 )
replace AK56A4 = . if (AK56A4 <= -1 )
replace AK56B4 = . if (AK56B4 <= -1 )
replace AK56B4_M = . if (AK56B4_M <= -1 )
replace AK56A5 = . if (AK56A5 <= -1 )
replace AK56B5 = . if (AK56B5 <= -1 )
replace AK56B5_M = . if (AK56B5_M <= -1 )
replace AK56A6 = . if (AK56A6 <= -1 )
replace AK56B6 = . if (AK56B6 <= -1 )
replace AK56B6_M = . if (AK56B6_M <= -1 )
replace AK56A7 = . if (AK56A7 <= -1 )
replace AK56B7 = . if (AK56B7 <= -1 )
replace AK56B7_M = . if (AK56B7_M <= -1 )
replace AK56A8 = . if (AK56A8 <= -1 )
replace AK56B8 = . if (AK56B8 <= -1 )
replace AK56B8_M = . if (AK56B8_M <= -1 )
replace AK7 = . if (AK7 <= -1 )
replace AK8 = . if (AK8 <= -1 )
replace AK78A1 = . if (AK78A1 <= -1 )
replace AK78B1 = . if (AK78B1 <= -1 )
replace AK78B1_M = . if (AK78B1_M <= -1 )
replace AK78A2 = . if (AK78A2 <= -1 )
replace AK78B2 = . if (AK78B2 <= -1 )
replace AK78B2_M = . if (AK78B2_M <= -1 )
replace AK78A4 = . if (AK78A4 <= -1 )
replace AK78B4 = . if (AK78B4 <= -1 )
replace AK78B4_M = . if (AK78B4_M <= -1 )
replace AK78A5 = . if (AK78A5 <= -1 )
replace AK78B5 = . if (AK78B5 <= -1 )
replace AK78B5_M = . if (AK78B5_M <= -1 )
replace AK78A6 = . if (AK78A6 <= -1 )
replace AK78B6 = . if (AK78B6 <= -1 )
replace AK78B6_M = . if (AK78B6_M <= -1 )
replace AK78A7 = . if (AK78A7 <= -1 )
replace AK78B7 = . if (AK78B7 <= -1 )
replace AK78B7_M = . if (AK78B7_M <= -1 )
replace AK78A8 = . if (AK78A8 <= -1 )
replace AK78B8 = . if (AK78B8 <= -1 )
replace AK78B8_M = . if (AK78B8_M <= -1 )
replace AK9 = . if (AK9 <= -1 )
replace AK9A1 = . if (AK9A1 <= -1 )
replace AK9B1 = . if (AK9B1 <= -1 )
replace AK9B1_M = . if (AK9B1_M <= -1 )
replace AK9A2 = . if (AK9A2 <= -1 )
replace AK9B2 = . if (AK9B2 <= -1 )
replace AK9B2_M = . if (AK9B2_M <= -1 )
replace AK9A4 = . if (AK9A4 <= -1 )
replace AK9B4 = . if (AK9B4 <= -1 )
replace AK9B4_M = . if (AK9B4_M <= -1 )
replace AK9A5 = . if (AK9A5 <= -1 )
replace AK9B5 = . if (AK9B5 <= -1 )
replace AK9B5_M = . if (AK9B5_M <= -1 )
replace AK9A6 = . if (AK9A6 <= -1 )
replace AK9B6 = . if (AK9B6 <= -1 )
replace AK9B6_M = . if (AK9B6_M <= -1 )
replace AK9A7 = . if (AK9A7 <= -1 )
replace AK9B7 = . if (AK9B7 <= -1 )
replace AK9B7_M = . if (AK9B7_M <= -1 )
replace AK9A8 = . if (AK9A8 <= -1 )
replace AK9B8 = . if (AK9B8 <= -1 )
replace AK9B8_M = . if (AK9B8_M <= -1 )
replace AK10 = . if (AK10 <= -1 )
replace AK10A = . if (AK10A <= -1 )
replace AK10B = . if (AK10B <= -1 )
replace AK10C = . if (AK10C <= -1 )
replace AK10C_M = . if (AK10C_M <= -1 )
replace AK11 = . if (AK11 <= -1 )
replace AK12 = . if (AK12 <= -1 )
replace AK13 = . if (AK13 <= -1 )
replace AK13_1A = . if (AK13_1A <= -1 )
replace AK13_1B = . if (AK13_1B <= -1 )
replace AK13_1C = . if (AK13_1C <= -1 )
replace AK13_1D = . if (AK13_1D <= -1 )
replace AK13_1DR = . if (AK13_1DR <= -1 )
replace AK13_3A = . if (AK13_3A <= -1 )
replace AK13_3B = . if (AK13_3B <= -1 )
replace AK13_3C = . if (AK13_3C <= -1 )
replace AK13_3D = . if (AK13_3D <= -1 )
replace AK13_3DR = . if (AK13_3DR <= -1 )
replace AK13_4A = . if (AK13_4A <= -1 )
replace AK13_4B = . if (AK13_4B <= -1 )
replace AK13_4C = . if (AK13_4C <= -1 )
replace AK13_4D = . if (AK13_4D <= -1 )
replace AK13_4DR = . if (AK13_4DR <= -1 )
replace AK13_5A = . if (AK13_5A <= -1 )
replace AK13_5B = . if (AK13_5B <= -1 )
replace AK13_5C = . if (AK13_5C <= -1 )
replace AK13_5D = . if (AK13_5D <= -1 )
replace AK13_5DR = . if (AK13_5DR <= -1 )
replace AK13_6A = . if (AK13_6A <= -1 )
replace AK13_6B = . if (AK13_6B <= -1 )
replace AK13_6C = . if (AK13_6C <= -1 )
replace AK13_6D = . if (AK13_6D <= -1 )
replace AK13_6DR = . if (AK13_6DR <= -1 )
replace AK13_7A = . if (AK13_7A <= -1 )
replace AK13_7B = . if (AK13_7B <= -1 )
replace AK13_7C = . if (AK13_7C <= -1 )
replace AK13_7D = . if (AK13_7D <= -1 )
replace AK13_7DR = . if (AK13_7DR <= -1 )
replace AK14 = . if (AK14 <= -1 )
replace AK14_1A = . if (AK14_1A <= -1 )
replace AK14_1B = . if (AK14_1B <= -1 )
replace AK14_1C = . if (AK14_1C <= -1 )
replace AK14_1CR = . if (AK14_1CR <= -1 )
replace AK14_2A = . if (AK14_2A <= -1 )
replace AK14_2B = . if (AK14_2B <= -1 )
replace AK14_2C = . if (AK14_2C <= -1 )
replace AK14_2CR = . if (AK14_2CR <= -1 )
replace AK14_4A = . if (AK14_4A <= -1 )
replace AK14_4B = . if (AK14_4B <= -1 )
replace AK14_4C = . if (AK14_4C <= -1 )
replace AK14_4CR = . if (AK14_4CR <= -1 )
replace AK14_5A = . if (AK14_5A <= -1 )
replace AK14_5B = . if (AK14_5B <= -1 )
replace AK14_5C = . if (AK14_5C <= -1 )
replace AK14_5CR = . if (AK14_5CR <= -1 )
replace AK14_6A = . if (AK14_6A <= -1 )
replace AK14_6B = . if (AK14_6B <= -1 )
replace AK14_6C = . if (AK14_6C <= -1 )
replace AK14_6CR = . if (AK14_6CR <= -1 )
replace AK14_7A = . if (AK14_7A <= -1 )
replace AK14_7B = . if (AK14_7B <= -1 )
replace AK14_7C = . if (AK14_7C <= -1 )
replace AK14_7CR = . if (AK14_7CR <= -1 )
replace AK14_8A = . if (AK14_8A <= -1 )
replace AK14_8B = . if (AK14_8B <= -1 )
replace AK14_8C = . if (AK14_8C <= -1 )
replace AK14_8CR = . if (AK14_8CR <= -1 )
replace AK15 = . if (AK15 <= -1 )
replace AK15_1A = . if (AK15_1A <= -1 )
replace AK15_1B = . if (AK15_1B <= -1 )
replace AK15_1C = . if (AK15_1C <= -1 )
replace AK15_1D = . if (AK15_1D <= -1 )
replace AK15_1DR = . if (AK15_1DR <= -1 )
replace AK15_2A = . if (AK15_2A <= -1 )
replace AK15_2B = . if (AK15_2B <= -1 )
replace AK15_2C = . if (AK15_2C <= -1 )
replace AK15_2D = . if (AK15_2D <= -1 )
replace AK15_2DR = . if (AK15_2DR <= -1 )
replace AK15_4A = . if (AK15_4A <= -1 )
replace AK15_4B = . if (AK15_4B <= -1 )
replace AK15_4C = . if (AK15_4C <= -1 )
replace AK15_4D = . if (AK15_4D <= -1 )
replace AK15_4DR = . if (AK15_4DR <= -1 )
replace AK15_5A = . if (AK15_5A <= -1 )
replace AK15_5B = . if (AK15_5B <= -1 )
replace AK15_5C = . if (AK15_5C <= -1 )
replace AK15_5D = . if (AK15_5D <= -1 )
replace AK15_5DR = . if (AK15_5DR <= -1 )
replace AK15_6A = . if (AK15_6A <= -1 )
replace AK15_6B = . if (AK15_6B <= -1 )
replace AK15_6C = . if (AK15_6C <= -1 )
replace AK15_6D = . if (AK15_6D <= -1 )
replace AK15_6DR = . if (AK15_6DR <= -1 )
replace AK15_7A = . if (AK15_7A <= -1 )
replace AK15_7B = . if (AK15_7B <= -1 )
replace AK15_7C = . if (AK15_7C <= -1 )
replace AK15_7D = . if (AK15_7D <= -1 )
replace AK15_7DR = . if (AK15_7DR <= -1 )
replace AK15_8A = . if (AK15_8A <= -1 )
replace AK15_8B = . if (AK15_8B <= -1 )
replace AK15_8C = . if (AK15_8C <= -1 )
replace AK15_8D = . if (AK15_8D <= -1 )
replace AK15_8DR = . if (AK15_8DR <= -1 )
replace AK16 = . if (AK16 <= -1 )
replace AK16A1 = . if (AK16A1 <= -1 )
replace AK16B1 = . if (AK16B1 <= -1 )
replace AK16B1_M = . if (AK16B1_M <= -1 )
replace AK16A2 = . if (AK16A2 <= -1 )
replace AK16B2 = . if (AK16B2 <= -1 )
replace AK16B2_M = . if (AK16B2_M <= -1 )
replace AK16A4 = . if (AK16A4 <= -1 )
replace AK16B4 = . if (AK16B4 <= -1 )
replace AK16B4_M = . if (AK16B4_M <= -1 )
replace AK16A5 = . if (AK16A5 <= -1 )
replace AK16B5 = . if (AK16B5 <= -1 )
replace AK16B5_M = . if (AK16B5_M <= -1 )
replace AK16A6 = . if (AK16A6 <= -1 )
replace AK16B6 = . if (AK16B6 <= -1 )
replace AK16A7 = . if (AK16A7 <= -1 )
replace AK16B7 = . if (AK16B7 <= -1 )
replace AK16B7_M = . if (AK16B7_M <= -1 )
replace AK16A8 = . if (AK16A8 <= -1 )
replace AK16B8 = . if (AK16B8 <= -1 )
replace AK16B8_M = . if (AK16B8_M <= -1 )
replace AK17 = . if (AK17 <= -1 )
replace AK17A1 = . if (AK17A1 <= -1 )
replace AK17B1 = . if (AK17B1 <= -1 )
replace AK17B1_M = . if (AK17B1_M <= -1 )
replace AK17A2 = . if (AK17A2 <= -1 )
replace AK17B2 = . if (AK17B2 <= -1 )
replace AK17B2_M = . if (AK17B2_M <= -1 )
replace AK17A4 = . if (AK17A4 <= -1 )
replace AK17B4 = . if (AK17B4 <= -1 )
replace AK17B4_M = . if (AK17B4_M <= -1 )
replace AK17A5 = . if (AK17A5 <= -1 )
replace AK17B5 = . if (AK17B5 <= -1 )
replace AK17B5_M = . if (AK17B5_M <= -1 )
replace AK17A6 = . if (AK17A6 <= -1 )
replace AK17B6 = . if (AK17B6 <= -1 )
replace AK17B6_M = . if (AK17B6_M <= -1 )
replace AK17A7 = . if (AK17A7 <= -1 )
replace AK17B7 = . if (AK17B7 <= -1 )
replace AK17B7_M = . if (AK17B7_M <= -1 )
replace AK17A8 = . if (AK17A8 <= -1 )
replace AK17B8 = . if (AK17B8 <= -1 )
replace AK17B8_M = . if (AK17B8_M <= -1 )
replace AK18 = . if (AK18 <= -1 )
replace AK18A = . if (AK18A <= -1 )
replace AK18B = . if (AK18B <= -1 )
replace AK18C = . if (AK18C <= -1 )
replace AK19 = . if (AK19 <= -1 )
replace AK19_1A = . if (AK19_1A <= -1 )
replace AK19_1B = . if (AK19_1B <= -1 )
replace AK19_1C = . if (AK19_1C <= -1 )
replace AK19_1D = . if (AK19_1D <= -1 )
replace AK19_1DR = . if (AK19_1DR <= -1 )
replace AK19_3A = . if (AK19_3A <= -1 )
replace AK19_3B = . if (AK19_3B <= -1 )
replace AK19_3C = . if (AK19_3C <= -1 )
replace AK19_3D = . if (AK19_3D <= -1 )
replace AK19_3DR = . if (AK19_3DR <= -1 )
replace AK19_4A = . if (AK19_4A <= -1 )
replace AK19_4B = . if (AK19_4B <= -1 )
replace AK19_4C = . if (AK19_4C <= -1 )
replace AK19_4D = . if (AK19_4D <= -1 )
replace AK19_4DR = . if (AK19_4DR <= -1 )
replace AK19_5A = . if (AK19_5A <= -1 )
replace AK19_5B = . if (AK19_5B <= -1 )
replace AK19_5C = . if (AK19_5C <= -1 )
replace AK19_5D = . if (AK19_5D <= -1 )
replace AK19_5DR = . if (AK19_5DR <= -1 )
replace AK19_6A = . if (AK19_6A <= -1 )
replace AK19_6B = . if (AK19_6B <= -1 )
replace AK19_6C = . if (AK19_6C <= -1 )
replace AK19_6D = . if (AK19_6D <= -1 )
replace AK19_6DR = . if (AK19_6DR <= -1 )
replace AK19_7A = . if (AK19_7A <= -1 )
replace AK19_7B = . if (AK19_7B <= -1 )
replace AK19_7C = . if (AK19_7C <= -1 )
replace AK19_7D = . if (AK19_7D <= -1 )
replace AK19_7DR = . if (AK19_7DR <= -1 )
replace AK20 = . if (AK20 <= -1 )
replace AK20_1A = . if (AK20_1A <= -1 )
replace AK20_1B = . if (AK20_1B <= -1 )
replace AK20_1C = . if (AK20_1C <= -1 )
replace AK20_1CR = . if (AK20_1CR <= -1 )
replace AK20_2A = . if (AK20_2A <= -1 )
replace AK20_2B = . if (AK20_2B <= -1 )
replace AK20_2C = . if (AK20_2C <= -1 )
replace AK20_2CR = . if (AK20_2CR <= -1 )
replace AK20_4A = . if (AK20_4A <= -1 )
replace AK20_4B = . if (AK20_4B <= -1 )
replace AK20_4C = . if (AK20_4C <= -1 )
replace AK20_4CR = . if (AK20_4CR <= -1 )
replace AK20_5A = . if (AK20_5A <= -1 )
replace AK20_5B = . if (AK20_5B <= -1 )
replace AK20_5C = . if (AK20_5C <= -1 )
replace AK20_5CR = . if (AK20_5CR <= -1 )
replace AK20_6A = . if (AK20_6A <= -1 )
replace AK20_6B = . if (AK20_6B <= -1 )
replace AK20_6C = . if (AK20_6C <= -1 )
replace AK20_6CR = . if (AK20_6CR <= -1 )
replace AK20_7A = . if (AK20_7A <= -1 )
replace AK20_7B = . if (AK20_7B <= -1 )
replace AK20_7C = . if (AK20_7C <= -1 )
replace AK20_7CR = . if (AK20_7CR <= -1 )
replace AK20_8A = . if (AK20_8A <= -1 )
replace AK20_8B = . if (AK20_8B <= -1 )
replace AK20_8C = . if (AK20_8C <= -1 )
replace AK20_8CR = . if (AK20_8CR <= -1 )
replace AK21 = . if (AK21 <= -1 )
replace AK21_1A = . if (AK21_1A <= -1 )
replace AK21_1B3 = . if (AK21_1B3 <= -1 )
replace AK21_1C = . if (AK21_1C <= -1 )
replace AK21_1CR = . if (AK21_1CR <= -1 )
replace AK21_2A = . if (AK21_2A <= -1 )
replace AK212B3 = . if (AK212B3 <= -1 )
replace AK21_2C = . if (AK21_2C <= -1 )
replace AK21_2CR = . if (AK21_2CR <= -1 )
replace AK21_4A = . if (AK21_4A <= -1 )
replace AK21_4B3 = . if (AK21_4B3 <= -1 )
replace AK21_4C = . if (AK21_4C <= -1 )
replace AK21_4CR = . if (AK21_4CR <= -1 )
replace AK21_5A = . if (AK21_5A <= -1 )
replace AK21_5B3 = . if (AK21_5B3 <= -1 )
replace AK21_5C = . if (AK21_5C <= -1 )
replace AK21_5CR = . if (AK21_5CR <= -1 )
replace AK21_6A = . if (AK21_6A <= -1 )
replace AK21_6B3 = . if (AK21_6B3 <= -1 )
replace AK21_6C = . if (AK21_6C <= -1 )
replace AK21_6CR = . if (AK21_6CR <= -1 )
replace AK21_7A = . if (AK21_7A <= -1 )
replace AK21_7B3 = . if (AK21_7B3 <= -1 )
replace AK21_7C = . if (AK21_7C <= -1 )
replace AK21_7CR = . if (AK21_7CR <= -1 )
replace AK21_8A = . if (AK21_8A <= -1 )
replace AK21_8B3 = . if (AK21_8B3 <= -1 )
replace AK21_8C = . if (AK21_8C <= -1 )
replace AK21_8CR = . if (AK21_8CR <= -1 )
replace AK22 = . if (AK22 <= -1 )
replace AK22_1A = . if (AK22_1A <= -1 )
replace AK22_1B = . if (AK22_1B <= -1 )
replace AK22_1C = . if (AK22_1C <= -1 )
replace AK22_1CR = . if (AK22_1CR <= -1 )
replace AK22_2A = . if (AK22_2A <= -1 )
replace AK22_2B = . if (AK22_2B <= -1 )
replace AK22_2C = . if (AK22_2C <= -1 )
replace AK22_2CR = . if (AK22_2CR <= -1 )
replace AK22_4A = . if (AK22_4A <= -1 )
replace AK22_4B = . if (AK22_4B <= -1 )
replace AK22_4C = . if (AK22_4C <= -1 )
replace AK22_4CR = . if (AK22_4CR <= -1 )
replace AK22_5A = . if (AK22_5A <= -1 )
replace AK22_5B = . if (AK22_5B <= -1 )
replace AK22_5C = . if (AK22_5C <= -1 )
replace AK22_5CR = . if (AK22_5CR <= -1 )
replace AK22_6A = . if (AK22_6A <= -1 )
replace AK22_6B = . if (AK22_6B <= -1 )
replace AK22_6C = . if (AK22_6C <= -1 )
replace AK22_6CR = . if (AK22_6CR <= -1 )
replace AK22_7A = . if (AK22_7A <= -1 )
replace AK22_7B = . if (AK22_7B <= -1 )
replace AK22_7C = . if (AK22_7C <= -1 )
replace AK22_7CR = . if (AK22_7CR <= -1 )
replace AK22_8A = . if (AK22_8A <= -1 )
replace AK22_8B = . if (AK22_8B <= -1 )
replace AK22_8C = . if (AK22_8C <= -1 )
replace AK22_8CR = . if (AK22_8CR <= -1 )
replace AK23_A = . if (AK23_A <= -1 )
replace AK23_B = . if (AK23_B <= -1 )
replace AK23_C = . if (AK23_C <= -1 )
replace AK23_D = . if (AK23_D <= -1 )
replace AK23_E = . if (AK23_E <= -1 )
replace AK23_F = . if (AK23_F <= -1 )
replace AK23_G = . if (AK23_G <= -1 )
replace AL1 = . if (AL1 <= -1 )
replace AL2 = . if (AL2 <= -1 )
replace AL2A = . if (AL2A <= -1 )
replace AL3_1_1 = . if (AL3_1_1 <= -1 )
replace AL3_1_2 = . if (AL3_1_2 <= -1 )
replace AL3_2_1 = . if (AL3_2_1 <= -1 )
replace AL3_2_2 = . if (AL3_2_2 <= -1 )
replace AL3_3_1 = . if (AL3_3_1 <= -1 )
replace AL3_3_2 = . if (AL3_3_2 <= -1 )
replace AL3_4_1 = . if (AL3_4_1 <= -1 )
replace AL3_4_2 = . if (AL3_4_2 <= -1 )
replace AL4 = . if (AL4 <= -1 )
replace AL4A1 = . if (AL4A1 <= -1 )
replace AL4A2 = . if (AL4A2 <= -1 )
replace AL4A3 = . if (AL4A3 <= -1 )
replace AL4A4 = . if (AL4A4 <= -1 )
replace AL4A5 = . if (AL4A5 <= -1 )
replace AL4A6 = . if (AL4A6 <= -1 )
replace AL5 = . if (AL5 <= -1 )
replace AL6 = . if (AL6 <= -1 )
replace AL6A1 = . if (AL6A1 <= -1 )
replace AL6A2 = . if (AL6A2 <= -1 )
replace AM1 = . if (AM1 <= -1 )
replace AM2 = . if (AM2 <= -1 )
replace AM3 = . if (AM3 <= -1 )
replace AM4 = . if (AM4 <= -1 )
replace AM5 = . if (AM5 <= -1 )
replace AM6 = . if (AM6 <= -1 )
replace AM7 = . if (AM7 <= -1 )
replace AM8 = . if (AM8 <= -1 )
replace AM9 = . if (AM9 <= -1 )
replace AM10A = . if (AM10A <= -1 )
replace AM10B = . if (AM10B <= -1 )
replace AM11A = . if (AM11A <= -1 )
replace AM11B = . if (AM11B <= -1 )
replace AM11C = . if (AM11C <= -1 )
replace AM12A = . if (AM12A <= -1 )
replace AM12B = . if (AM12B <= -1 )
replace AM12C = . if (AM12C <= -1 )
replace AM12D = . if (AM12D <= -1 )
replace AM12E = . if (AM12E <= -1 )
replace AM13 = . if (AM13 <= -1 )
replace AM14A = . if (AM14A <= -1 )
replace AM14B = . if (AM14B <= -1 )
replace AM14C = . if (AM14C <= -1 )
replace AM15A = . if (AM15A <= -1 )
replace AM15B = . if (AM15B <= -1 )
replace AM16 = . if (AM16 <= -1 )
replace AM17 = . if (AM17 <= -1 )
replace AM18A = . if (AM18A <= -1 )
replace AM18B = . if (AM18B <= -1 )
replace AM18C = . if (AM18C <= -1 )
replace AM19 = . if (AM19 <= -1 )
replace AM20 = . if (AM20 <= -1 )
replace AM21 = . if (AM21 <= -1 )
replace AGE = . if (AGE <= -1 )
replace AGEGRP = . if (AGEGRP <= -1 )
replace MSTAT = . if (MSTAT <= -1 )
replace FTWORK = . if (FTWORK <= -1 )
replace EDLEV = . if (EDLEV <= -1 )
replace HLTHINS = . if (HLTHINS <= -1 )
replace MAJSRC = . if (MAJSRC <= -1 )
replace REFER = . if (REFER <= -1 )
replace CJ_STAT = . if (CJ_STAT <= -1 )
replace RESTRICT = . if (RESTRICT <= -1 )
replace PDRUG = . if (PDRUG <= -1 )
replace PDRUGFRQ = . if (PDRUGFRQ <= -1 )
replace FAVDRUG = . if (FAVDRUG <= -1 )
replace HVY_ALC = . if (HVY_ALC <= -1 )
replace ALCWK = . if (ALCWK <= -1 )
replace MRJWK = . if (MRJWK <= -1 )
replace COCWK = . if (COCWK <= -1 )
replace CRKWK = . if (CRKWK <= -1 )
replace HERWK = . if (HERWK <= -1 )
replace NARWK = . if (NARWK <= -1 )
replace SEDWK = . if (SEDWK <= -1 )
replace AMPWK = . if (AMPWK <= -1 )
replace HALWK = . if (HALWK <= -1 )
replace INHWK = . if (INHWK <= -1 )
replace HERHX = . if (HERHX <= -1 )
replace COCHX = . if (COCHX <= -1 )
replace DRUGTX = . if (DRUGTX <= -1 )
replace DRGTXAGE = . if (DRGTXAGE <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

